<?php

$LANG = array(
    'organization' => 'Organizata',
    'name' => 'Emri',
    'website' => 'Website',
    'work_phone' => 'Telefoni',
    'address' => 'Adresa',
    'address1' => 'Rruga',
    'address2' => 'Apartamenti/banesa',
    'city' => 'Qyteti',
    'state' => 'Shteti/Provinca',
    'postal_code' => 'Kodi postar',
    'country_id' => 'Shteti',
    'contacts' => 'Kontaktet',
    'first_name' => 'Emri',
    'last_name' => 'Mbiemri',
    'phone' => 'Telefoni',
    'email' => 'Emaili',
    'additional_info' => 'Info shtesë',
    'payment_terms' => 'Kushtet e pagesës',
    'currency_id' => 'Valuta',
    'size_id' => 'Madhësia e kompanisë',
    'industry_id' => 'Industria',
    'private_notes' => 'Shënime private',
    'invoice' => 'Fatura',
    'client' => 'Klient',
    'invoice_date' => 'Data e faturës',
    'due_date' => 'Deri më datë',
    'invoice_number' => 'Numri i faturës',
    'invoice_number_short' => '# faturës',
    'po_number' => 'Numri UB',
    'po_number_short' => '#UB',
    'frequency_id' => 'Sa shpesh',
    'discount' => 'Zbritje',
    'taxes' => 'Taksat',
    'tax' => 'Taksë',
    'item' => 'Njësi',
    'description' => 'Përshkrimi',
    'unit_cost' => 'Kosto për njësi',
    'quantity' => 'Sasia',
    'line_total' => 'Totali i linjës',
    'subtotal' => 'Nëntotali',
    'paid_to_date' => 'Paguar deri më sot',
    'balance_due' => 'Bilanci aktual',
    'invoice_design_id' => 'Dizajni',
    'terms' => 'Kushtet',
    'your_invoice' => 'Fatura juaj',
    'remove_contact' => 'Fshi kontaktin',
    'add_contact' => 'Shto kontaktin',
    'create_new_client' => 'Krijo klient të ri',
    'edit_client_details' => 'Ndrysho detajet e klientit',
    'enable' => 'Aktivizo',
    'learn_more' => 'Mëso më shumë',
    'manage_rates' => 'Menaxho normat',
    'note_to_client' => 'Shënime për klientin',
    'invoice_terms' => 'Kushtet e faturës',
    'save_as_default_terms' => 'Ruaj si njësi e paracaktuar',
    'download_pdf' => 'Shkarko PDF',
    'pay_now' => 'Paguaj Tani',
    'save_invoice' => 'Ruaj faturën',
    'clone_invoice' => 'Clone To Invoice',
    'archive_invoice' => 'Arkivo faturën',
    'delete_invoice' => 'Fshi faturën',
    'email_invoice' => 'Dërgo faturën me email',
    'enter_payment' => 'Cakto pagesën',
    'tax_rates' => 'Normat e taksave',
    'rate' => 'Norma',
    'settings' => 'Rregullimet',
    'enable_invoice_tax' => 'Mundëso specifikimin e <b>invoice tax</b>',
    'enable_line_item_tax' => 'Mundëso specifikimin e <b>line item taxes</b>',
    'dashboard' => 'Paneli',
    'dashboard_totals_in_all_currencies_help' => 'Note: add a :link named ":name" to show the totals using a single base currency.',
    'clients' => 'Klientët',
    'invoices' => 'Faturat',
    'payments' => 'Pagesat',
    'credits' => 'Kredi',
    'history' => 'Historia',
    'search' => 'Kërko',
    'sign_up' => 'Regjistrohu',
    'guest' => 'Vizitor',
    'company_details' => 'Detajet e kompanisë',
    'online_payments' => 'Pagesat Online',
    'notifications' => 'Njoftimet',
    'import_export' => 'Import | Export',
    'done' => 'Përfundo',
    'save' => 'Ruaj',
    'create' => 'Krijo',
    'upload' => 'Ngarko',
    'import' => 'Importo',
    'download' => 'Shkarko',
    'cancel' => 'Anulo',
    'close' => 'Mbyll',
    'provide_email' => 'Ju lutem vendosni një adresë email ',
    'powered_by' => 'Mundësuar nga',
    'no_items' => 'Nuk ka artikuj',
    'recurring_invoices' => 'Fatura të përsëritshme',
    'recurring_help' => '<p>Automatically send clients the same invoices weekly, bi-monthly, monthly, quarterly or annually. </p>
        <p>Use :MONTH, :QUARTER or :YEAR for dynamic dates. Basic math works as well, for example :MONTH-1.</p>
        <p>Examples of dynamic invoice variables:</p>
        <ul>
          <li>"Gym membership for the month of :MONTH" >> "Gym membership for the month of July"</li>
          <li>":YEAR+1 yearly subscription" >> "2015 Yearly Subscription"</li>
          <li>"Retainer payment for :QUARTER+1" >> "Retainer payment for Q2"</li>
        </ul>',
    'recurring_quotes' => 'Recurring Quotes',
    'in_total_revenue' => 'në total qarkullim',
    'billed_client' => 'klienti i faturuar',
    'billed_clients' => 'klientët e faturuar',
    'active_client' => 'klient aktiv',
    'active_clients' => 'klientë aktiv',
    'invoices_past_due' => 'Faturuar deri më',
    'upcoming_invoices' => 'Faturat e ardhshme',
    'average_invoice' => 'Mesatarja e faturës',
    'archive' => 'Arkivo',
    'delete' => 'Fshi',
    'archive_client' => 'Arkivo Klientin',
    'delete_client' => 'Fshi Klientin',
    'archive_payment' => 'Arkivo Pagesën',
    'delete_payment' => 'Fshi Pagesën',
    'archive_credit' => 'Arkivo Kreditin',
    'delete_credit' => 'Fshi Kreditin',
    'show_archived_deleted' => 'Shfaq të arkivuara/fshira',
    'filter' => 'Filtro',
    'new_client' => 'Klient i ri',
    'new_invoice' => 'Faturë e re',
    'new_payment' => 'Enter Payment',
    'new_credit' => 'Enter Credit',
    'contact' => 'Kontakt',
    'date_created' => 'Data e krijimit',
    'last_login' => 'Hera e fundit që është lidhur',
    'balance' => 'Bilanci',
    'action' => 'Vepro',
    'status' => 'Statusi',
    'invoice_total' => 'Totali i faturës',
    'frequency' => 'Frekuenca',
    'range' => 'Range',
    'start_date' => 'Data e fillimit',
    'end_date' => 'Data e përfundimit',
    'transaction_reference' => 'Referenca e transaksionit',
    'method' => 'Metoda',
    'payment_amount' => 'Shuma e paguar',
    'payment_date' => 'Data e pagesës',
    'credit_amount' => 'Shuma e kredituar',
    'credit_balance' => 'Bilanci i kreditit',
    'credit_date' => 'Data e kreditit',
    'empty_table' => 'Nuk ka të dhëna në tabelë',
    'select' => 'Selekto',
    'edit_client' => 'Edito klientin',
    'edit_invoice' => 'Edito Faturën',
    'create_invoice' => 'Krijo faturë',
    'enter_credit' => 'Vendos Kredi',
    'last_logged_in' => 'Hera e fundit që është lidhur',
    'details' => 'Detajet',
    'standing' => 'Gjendja',
    'credit' => 'Kredi',
    'activity' => 'Aktiviteti',
    'date' => 'Data',
    'message' => 'Mesazhi',
    'adjustment' => 'Rregullo',
    'are_you_sure' => 'A jeni të sigurtë',
    'payment_type_id' => 'Lloji i pagesës',
    'amount' => 'Shuma',
    'work_email' => 'Email',
    'language_id' => 'Gjuha',
    'timezone_id' => 'Zona kohore',
    'date_format_id' => 'Formati i datës',
    'datetime_format_id' => 'Formati i datës/kohës',
    'users' => 'Përdorues',
    'localization' => 'Vendore',
    'remove_logo' => 'Largo logon',
    'logo_help' => 'Të përkrahura: JPEG, GIF dhe PNG',
    'payment_gateway' => 'Kanali i pagesës',
    'gateway_id' => 'Kanali',
    'email_notifications' => 'Njoftime me email',
    'email_sent' => 'Më dërgo email kur fatura <b>dërgohet</b>',
    'email_viewed' => 'Më dërgo email kur fature <b>shikohet</b>',
    'email_paid' => 'Më dërgo email kur fatura <b>paguhet</b>',
    'site_updates' => 'Perditesimet e faqes',
    'custom_messages' => 'Mesazh i ndryshëm',
    'default_email_footer' => 'Vendosni <b>nënshkrimin e emailit</>',
    'select_file' => 'Ju lutem zgjedhni një fajll',
    'first_row_headers' => 'Përdorni rreshtin e parë si titull',
    'column' => 'Kolona',
    'sample' => 'Shembull',
    'import_to' => 'Importo në',
    'client_will_create' => 'klienti do të krijohet',
    'clients_will_create' => 'klientët do të krijohen',
    'email_settings' => 'Rregullimi i Emailit',
    'client_view_styling' => 'Stili i shikimit të klientëve',
    'pdf_email_attachment' => 'Bashkangjit PDF',
    'custom_css' => 'CSS i ndryshushëm',
    'import_clients' => 'Importo të dhënat për klient',
    'csv_file' => 'Skedar CSV ',
    'export_clients' => 'Exporto të dhënat për klient',
    'created_client' => 'Klienti është krijuar me sukses',
    'created_clients' => 'Me sukses janë krijuar: count klienta',
    'updated_settings' => 'Të dhënat janë ndryshuar me sukses',
    'removed_logo' => 'Logo është larguar me sukses',
    'sent_message' => 'Mesazhi është dërguar me sukses',
    'invoice_error' => 'Ju lutem sigurohuni të zgjidhni një klient dhe të përmirësoni çdo gabim',
    'limit_clients' => 'Na falni, kjo tejkalon numrin prej :count klientëve',
    'payment_error' => 'Ka ndodhur një gabim gjatë procesimit të pagesës tuaj. Ju lutem provoni më vonë',
    'registration_required' => 'Ju lutem regjistrohuni që të keni mundësi ta dërgoni faturën me email',
    'confirmation_required' => 'Ju lutem konfirmoni email adresën tuaj, :link për të ri-dërguar emailin e konfirmimit. ',
    'updated_client' => 'Klienti është perditesuar me sukses',
    'archived_client' => 'Klienti është arkivuar me sukses',
    'archived_clients' => ':count klientë janë arkivuar me sukses',
    'deleted_client' => 'Klienti është fshirë me sukses',
    'deleted_clients' => ':count klientë janë fshirë me sukses',
    'updated_invoice' => 'Fatura është perditesuar me sukses',
    'created_invoice' => 'Fatura është krijuar me sukses',
    'cloned_invoice' => 'Fatura është klonuar me sukses',
    'emailed_invoice' => 'Fatura është dërguar me sukses me email',
    'and_created_client' => 'dhe ka krijuar klient',
    'archived_invoice' => 'Fatura është arkivuar me sukses',
    'archived_invoices' => ':count fatura janë arkivuar me sukes',
    'deleted_invoice' => 'Fatura është fshirë me sukses',
    'deleted_invoices' => ':count fatura janë fshirë me sukses',
    'created_payment' => 'Pagesa është krijuar me sukses',
    'created_payments' => ':count pagesa janë krijuar me sukses',
    'archived_payment' => 'Pagesa është arkivuar me sukses',
    'archived_payments' => ':count pagesa janë arkivuar me sukses',
    'deleted_payment' => 'Pagesa është fshirë me sukses',
    'deleted_payments' => ':count pagesa janë fshirë me sukses',
    'applied_payment' => 'Pagesa është aplikuar me sukses',
    'created_credit' => 'Krediti është krijuar me sukses',
    'archived_credit' => 'Krediti është arkivuar me sukses',
    'archived_credits' => ':count kredite janë arkivuar me sukses',
    'deleted_credit' => 'Krediti është fshirë me sukses',
    'deleted_credits' => ':kredi janë fshirë me sukses',
    'imported_file' => 'Skedari është importuar me sukses',
    'updated_vendor' => 'Kompania është perditesuar me sukses',
    'created_vendor' => 'Kompania është krijuar me sukses',
    'archived_vendor' => 'Kompania është arkivuar me sukses',
    'archived_vendors' => ':counts kompani janë arkivuar me sukses',
    'deleted_vendor' => 'Kompania është fshirë me sukses',
    'deleted_vendors' => ':count kompani janë fshirë me sukses',
    'confirmation_subject' => 'Konfirmimi i llogarisë për faturim',
    'confirmation_header' => 'Konfirmimi i llogarisë',
    'confirmation_message' => 'Ju lutem klikoni linkun më poshtë që të konfirmoni llogarinë tuaj',
    'invoice_subject' => 'Faturë e re :number nga :account',
    'invoice_message' => 'Për të shikuar faturën tuaj për :amount, klikoni linkun më poshtë',
    'payment_subject' => 'Pagesa është pranuar',
    'payment_message' => 'Ju faleminderit për pagesën prej :amount',
    'email_salutation' => 'I,e nderuar name:',
    'email_signature' => 'Përshëndetje',
    'email_from' => 'Ekipi i faturimit',
    'invoice_link_message' => 'Për të parë faturën klikoni linkun më poshtë:',
    'notification_invoice_paid_subject' => 'Fatura :invoice është paguar nga :client',
    'notification_invoice_sent_subject' => 'Fatura :invoice i është dërguar :client',
    'notification_invoice_viewed_subject' => 'Fatura :invoice është parë nga :client',
    'notification_invoice_paid' => 'Pagesa prej :amount është realizuar nga :client për faturën :invoice.',
    'notification_invoice_sent' => 'Klienti :client ka dërguar me email faturën :invoice për shumën :amount',
    'notification_invoice_viewed' => 'Klienti :client ka shikuar faturën :invoice për shumën :amount',
    'reset_password' => 'Ju mund ta resetoni fjalëkalimin e llogarisë tuaj duke klikuar butonin më poshtë:',
    'secure_payment' => 'Pagesë e sigurtë',
    'card_number' => 'Numri i kartës',
    'expiration_month' => 'Muji i skadimit',
    'expiration_year' => 'Viti i skadimit',
    'cvv' => 'CVV',
    'logout' => 'Ç\'identifikohu',
    'sign_up_to_save' => 'Regjistrohuni për të ruajtuar punën tuaj',
    'agree_to_terms' => 'Unë pajtohem me :terms',
    'terms_of_service' => 'Kushtet e shërbimit',
    'email_taken' => 'Kjo e-mail adresë tashmë është regjistruar',
    'working' => 'Duke punuar',
    'success' => 'Sukses',
    'success_message' => 'Ju jeni regjistruar me sukses! Ju lutem vizitoni linkun në emailin e konfirmimit për të verifikuar email adresën tuaj.',
    'erase_data' => 'Your account is not registered, this will permanently erase your data.',
    'password' => 'Fjalëkalimi',
    'pro_plan_product' => 'Pro Plani',
    'pro_plan_success' => 'Ju faleminderit që keni zgjedhur Invoice Ninja Pro plan!<p/>&nbsp;<br/>
                          <b>Next Steps</b><p/>Një faturë për pagesë ju është dërguar në email. Për të përdorur të gjitha opsionet e paketës Pro, ju lutem përcjellni udhëzimet në faturë për të realizuar pagesën.<p/>
                          Nuk mund ta gjeni faturën? Ju duhet asistencë shtesë? Jemi të lumtur t\'ju ndihmojmë
                          -- na dërgoni email në contact@invoiceninja.com',
    'unsaved_changes' => 'Keni ndryshime të pa ruajtura',
    'custom_fields' => 'Fushat e ndryshueshme',
    'company_fields' => 'Fushat e kompanisë',
    'client_fields' => 'Fushat e klientit',
    'field_label' => 'Fusha e etiketave',
    'field_value' => 'Fusha e vlerës',
    'edit' => 'Edito',
    'set_name' => 'Vendosni emrin e kompanisë tuaj',
    'view_as_recipient' => 'Shikojeni si pranuesi',
    'product_library' => 'Libraria e produkteve',
    'product' => 'Produkt',
    'products' => 'Produktet',
    'fill_products' => 'Plotëso-automatikisht produktet',
    'fill_products_help' => 'Duke zgjedhur produktin, automatikisht do të plotësohen <b>fill in the description and cost</b>',
    'update_products' => 'Perditeso-automatikisht produktet',
    'update_products_help' => 'Perditesimi i faturës automatikisht do të <b>perditesoje librarine e produktit</b>',
    'create_product' => 'Shto produkt',
    'edit_product' => 'Edito produkt',
    'archive_product' => 'Arkivo produktin',
    'updated_product' => 'Produkti është perditesuar me sukses',
    'created_product' => 'Produkti është krijuar me sukses',
    'archived_product' => 'Produkti është arkivuar me sukses',
    'pro_plan_custom_fields' => ':;link për të aktivizuar fushat e ndyrshueshme duke iu bashkuar Pro Planit',
    'advanced_settings' => 'Rregullimi i Avansuar',
    'pro_plan_advanced_settings' => '\'link për të aktivizuar rregullimin e avansuar, duke iu bashkuar Pro Planit',
    'invoice_design' => 'Dizajni i Faturës',
    'specify_colors' => 'Cakto ngjyrën',
    'specify_colors_label' => 'Zgjedhni ngjyrën që përdoret në faturë',
    'chart_builder' => 'Ndërtuesi i grafikoneve',
    'ninja_email_footer' => 'Created by :site | Create. Send. Get Paid.',
    'go_pro' => 'Abonuhoni Pro',
    'quote' => 'Ofertë',
    'quotes' => 'Oferta',
    'quote_number' => 'Numri i ofertës',
    'quote_number_short' => '# Ofertës',
    'quote_date' => 'Data e Ofertës',
    'quote_total' => 'Totali i Ofertës',
    'your_quote' => 'Oferta juaj',
    'total' => 'Totali',
    'clone' => 'Klono',
    'new_quote' => 'Ofertë e re',
    'create_quote' => 'Krijo Ofertë',
    'edit_quote' => 'Edito Ofertën',
    'archive_quote' => 'Arkivo Ofertën',
    'delete_quote' => 'Fshi Ofertën',
    'save_quote' => 'Ruaj Ofertën',
    'email_quote' => 'Dërgo me email Ofertën',
    'clone_quote' => 'Clone To Quote',
    'convert_to_invoice' => 'Ktheje Ofertën në Faturë',
    'view_invoice' => 'Shiko Faturën',
    'view_client' => 'Shiko Klientin',
    'view_quote' => 'Shiko Ofertën',
    'updated_quote' => 'Oferta është perditesuar me sukses',
    'created_quote' => 'Oferta është krijuar me sukses',
    'cloned_quote' => 'Oferta është klonuar me sukses',
    'emailed_quote' => 'Oferta është dërguar me sukses me email',
    'archived_quote' => 'Oferta është arkivuar me sukses',
    'archived_quotes' => ': count oferta janë arkivuar me sukses',
    'deleted_quote' => 'Oferta është fshirë me sukses',
    'deleted_quotes' => ':count oferta janë fshirë me sukses',
    'converted_to_invoice' => 'Oferta është konvertua rme sukses në Faturë',
    'quote_subject' => 'Ofertë e re me numër :number nga :account',
    'quote_message' => 'Për të shikuar ofertën për :amount, klikoni linkun më poshtë.',
    'quote_link_message' => 'Për të shikuar ofertat për klientin tuaj klikoni linkun më poshtë:',
    'notification_quote_sent_subject' => 'Oferta :invoice i është dërguar :client',
    'notification_quote_viewed_subject' => 'Oferta :invoice është shikuar nga :client',
    'notification_quote_sent' => 'Klientit :client i është dërguar me email Oferta :invoice për shumën :amount',
    'notification_quote_viewed' => 'Klienti :client ka shikuar Ofertën :invoice për shumën :amount.',
    'session_expired' => 'Seanca juaj ka skaduar.',
    'invoice_fields' => 'Fushat e faturës',
    'invoice_options' => 'Opsionet e faturës',
    'hide_paid_to_date' => 'Fshihe Paguar deri më tash',
    'hide_paid_to_date_help' => 'Shfaqni "Paguar deri më tash" në faturat tuaja pasi të jetë pranuar pagesa.',
    'charge_taxes' => 'Vendos taksat',
    'user_management' => 'Menaxhimi i përdoruesve',
    'add_user' => 'Shto Përdorues',
    'send_invite' => 'Dërgo Ftesë',
    'sent_invite' => 'Ftesa është dërguar me sukses',
    'updated_user' => 'Përdoruesi është perditesuar me sukses',
    'invitation_message' => 'Ju jeni ftuar nga :invitor.',
    'register_to_add_user' => 'Ju lutem regjistrohuni të shtoni përdoruesit',
    'user_state' => 'Shteti',
    'edit_user' => 'Edito përdoruesin',
    'delete_user' => 'Fshi Përdoruesin',
    'active' => 'Aktiv',
    'pending' => 'Në pritje',
    'deleted_user' => 'Përdoruesi është fshirë me sukses',
    'confirm_email_invoice' => 'A jeni i sigurtë që dëshironi ta dërgoni faturën me email?',
    'confirm_email_quote' => 'A jeni i sigurtë që dëshironi ta dërgoni me email këtë ofertë?',
    'confirm_recurring_email_invoice' => 'A jeni i sigurtë që kjo faturë të dërgohet me email?',
    'confirm_recurring_email_invoice_not_sent' => 'Are you sure you want to start the recurrence?',
    'cancel_account' => 'Fshi llogarinë',
    'cancel_account_message' => 'Vërrejtje: Kjo do të fshijë të gjitha të dhënat tuaja, ky veprim nuk ka mundësi të kthehet mbrapa.',
    'go_back' => 'Shkoni prapa',
    'data_visualizations' => 'Vizualizimi i të dhënave',
    'sample_data' => 'Të dhëna shembull janë shfaqur',
    'hide' => 'Fshih',
    'new_version_available' => 'Versioni i ri i :releases_link është në dispozicion. Ju jeni duke përdorur versionin :user_version, versioni më i ri është :latest_version',
    'invoice_settings' => 'Rregullimi i Faturës',
    'invoice_number_prefix' => 'Prefixi i numrit të faturës',
    'invoice_number_counter' => 'Numruesi i numrit të faturës',
    'quote_number_prefix' => 'Prefixi i numrit të ofertës',
    'quote_number_counter' => 'Numruesi i numrit të ofertës',
    'share_invoice_counter' => 'Shpërndaje numruesin e faturave',
    'invoice_issued_to' => 'Fatura i është lëshuar',
    'invalid_counter' => 'Për të shmangur konfliktin e mundshëm ju lutem vendosni prefiks tek fatura dhe oferta',
    'mark_sent' => 'Shenja është dërguar ',
    'gateway_help_1' => ':link për t\'u regjistruar në Authorize.net',
    'gateway_help_2' => ':link për tu regjistuar në Authorize.net',
    'gateway_help_17' => ':link për të marrë të dhënat tuaja nga PayPal.',
    'gateway_help_27' => ':link për tu regjistruar në 2Checkout.com. Për t\'u siguaruar që pagesat realizohen vendosni :complete_link si URL ridrejtues tek Account>SIte Management në portalin e 2Checkout.',
    'gateway_help_60' => ':link to create a WePay account.',
    'more_designs' => 'Më shumë dizajne',
    'more_designs_title' => 'Dizajne shtesë të faturave',
    'more_designs_cloud_header' => 'Bleni verisionin Pro për më shumë dizajne të faturave',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Blej',
    'bought_designs' => 'Janë shtuar me sukses dizajne tjera të faturave',
    'sent' => 'Dërguar',
    'vat_number' => 'Numri i TVSH',
    'timesheets' => 'Oraret',
    'payment_title' => 'Vendosni Adresën tuaj të faturimit dhe informacionet e Kredit Kartës',
    'payment_cvv' => '* Ky është numri 3-4 shifror në pjesën e prapme të kartelës tuaj',
    'payment_footer1' => '*Adresa e faturimit duhet të jetë e njejtë me atë në kredit kartë',
    'payment_footer2' => '* Ju lutem klikoni "PAGUAJ TASH" vetëm një herë - transaksioni mund të zgjat rreth 1 minutë për t\'u procesuar.',
    'id_number' => 'ID numri',
    'white_label_link' => 'White label',
    'white_label_header' => 'White Label',
    'bought_white_label' => 'Është aktivizuar me sukses licensa White Label',
    'white_labeled' => 'White labeled',
    'restore' => 'Rikthe',
    'restore_invoice' => 'Rikthe Faturën',
    'restore_quote' => 'Rikthe Ofertën',
    'restore_client' => 'Rikthe Klientin',
    'restore_credit' => 'Rikthe Kreditin',
    'restore_payment' => 'Rikthe Pagesën',
    'restored_invoice' => 'Fatura është rikthyer me sukses',
    'restored_quote' => 'Oferta është rikthyer me sukses',
    'restored_client' => 'Klienti është rikthyer me sukses',
    'restored_payment' => 'Pagesa është rikthyer me sukses',
    'restored_credit' => 'Krediti është rikhyer me sukses',
    'reason_for_canceling' => 'Na ndihmoni ta përmirësojmë faqen tonë duke na treguar pse po largoheni.',
    'discount_percent' => 'Përqindje',
    'discount_amount' => 'Shuma',
    'invoice_history' => 'Historia e Faturës',
    'quote_history' => 'Historia e Ofertës',
    'current_version' => 'Versioni aktual',
    'select_version' => 'Zgjidh versionin',
    'view_history' => 'Shiko Historinë',
    'edit_payment' => 'Edito Pagesën',
    'updated_payment' => 'Pagesa është perditesuar me sukses',
    'deleted' => 'E fshirë',
    'restore_user' => 'Rikthe Përdoruesin',
    'restored_user' => 'Përdoruesi është rikthyer me sukses',
    'show_deleted_users' => 'Shfaq përdoruesit e fshirë',
    'email_templates' => 'Shabllonet e email',
    'invoice_email' => 'Emaili i Faturës',
    'payment_email' => 'Emaili i Pagesës',
    'quote_email' => 'Emaili i Ofertës',
    'reset_all' => 'Reseto të gjitha',
    'approve' => 'Aprovo',
    'token_billing_type_id' => 'Faturimi me Token',
    'token_billing_help' => 'Store payment details with WePay, Stripe, Braintree or GoCardless.',
    'token_billing_1' => 'E ç\'aktivizuar',
    'token_billing_2' => 'Kutia  e hyrjes është shfaqur por nuk është zgjedhur',
    'token_billing_3' => 'Kutia e daljes është shfaqur por nuk është zgjedhur',
    'token_billing_4' => 'Gjithmonë',
    'token_billing_checkbox' => 'Ruaj të dhënat e kartës së kreditit',
    'view_in_gateway' => 'Shiko në :gateway',
    'use_card_on_file' => 'Përdorni kartelën nga fajlli',
    'edit_payment_details' => 'Edito detajet e pagesës',
    'token_billing' => 'Ruaj detajet e pagesës',
    'token_billing_secure' => 'Të dhënat janë ruajtur sigurtë nga :link',
    'support' => 'Përkrahja',
    'contact_information' => 'Informata e kontaktit',
    '256_encryption' => 'Enkriptim 256-Bit',
    'amount_due' => 'Shuma borxh',
    'billing_address' => 'Adresa e faturimit',
    'billing_method' => 'Metoda e faturimit',
    'order_overview' => 'Rishiqimi i porosisë',
    'match_address' => '*Adresa e faturimit duhet të jetë e njejtë me atë në kredit kartë',
    'click_once' => '* Ju lutem klikoni "PAGUAJ TASH" vetëm një herë - transaksioni mund të zgjat rreth 1 minutë për t\'u procesuar.',
    'invoice_footer' => 'Footer i Faturës',
    'save_as_default_footer' => 'Ruaj si footer i paracaktuar',
    'token_management' => 'Menaxhimi i Tokenit',
    'tokens' => 'Tokenët',
    'add_token' => 'Shto Token',
    'show_deleted_tokens' => 'Shfaq tokenët e fshirë',
    'deleted_token' => 'Tokeni është fshirë me sukses',
    'created_token' => 'Tokeni është fshirë me sukses',
    'updated_token' => 'Tokeni është perditesuar me sukses',
    'edit_token' => 'Edito Tokenin',
    'delete_token' => 'Fshi Tokenin',
    'token' => 'Token',
    'add_gateway' => 'Shto kanalin e pagesës',
    'delete_gateway' => 'Fshi kanalin e pagesës',
    'edit_gateway' => 'Edito kanalin e pagesës',
    'updated_gateway' => 'Kanali i pagesës është perditesuar me sukses',
    'created_gateway' => 'Kanali i pagesës është krijuar me sukses',
    'deleted_gateway' => 'Kanali i pagesës është fshirë me sukses',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Kredit Kartë',
    'change_password' => 'Ndrysho fjalëkalimin',
    'current_password' => 'Fjalëkalimi aktual',
    'new_password' => 'Fjalëkalim i ri',
    'confirm_password' => 'Konfimo fjalëkalimin',
    'password_error_incorrect' => 'Fjalëkalimi aktual nuk është i saktë.',
    'password_error_invalid' => 'Fjalëkalimi i ri nuk është i saktë.',
    'updated_password' => 'Fjalëkalimi është perditesuar me sukses',
    'api_tokens' => 'API Tokenët',
    'users_and_tokens' => 'Përdoruesit & Tokenët',
    'account_login' => 'Hyrja me llogari',
    'recover_password' => 'Riktheni fjalëkalimin tuaj',
    'forgot_password' => 'Keni harruar fjalëkalimin?',
    'email_address' => 'Email adresa',
    'lets_go' => 'Të shkojmë',
    'password_recovery' => 'Rikthimi i fjalëkalimit',
    'send_email' => 'Dërgo email',
    'set_password' => 'Vendos Fjalëkalim',
    'converted' => 'Konvertuar',
    'email_approved' => 'Më dërgo email kur oferta është <b>aprovuar</b>',
    'notification_quote_approved_subject' => 'Oferta :invoice është aprovuar nga :client',
    'notification_quote_approved' => 'Klienti :client ka aprovuar Ofertën :invoice për :amount.',
    'resend_confirmation' => 'Ridërgo emailin e konfirmimit',
    'confirmation_resent' => 'Emaili i konfirmimit është ridërguar.',
    'gateway_help_42' => ':link për tu regjistruar në BitPay. <br/> Shënim: përdorni Legacy API Key, jo API token.',
    'payment_type_credit_card' => 'Kredit Kartë',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Baza e njohurive',
    'partial' => 'E pjesshme/depozite',
    'partial_remaining' => ':partial nga :balance',
    'more_fields' => 'Më shumë fusha',
    'less_fields' => 'Më pak fusha',
    'client_name' => 'Emri i klientit',
    'pdf_settings' => 'Rregullimet e PDF',
    'product_settings' => 'Rregullimi i Produktit',
    'auto_wrap' => 'Mbushja automatike',
    'duplicate_post' => 'Vërejtje: faqja e kaluar është aplikuar dy herë. Aplikimi i dytë është injoruar.',
    'view_documentation' => 'Shiko Dokumentimin',
    'app_title' => 'Faturim Online Open-Source',
    'app_description' => 'Invoice Ninja është zgjidhje falas, open-cource për faturim të konsumatorëve. Me Invoice Ninjca, ju lehtësisht mund të krijoni dhe dërgoni fatura të bukura nga cilado pajisje e cila ka qasje në internet. Klientët tuaj mund të printojnë faturat, t\'i shkarkojnë si PDF fajlla apo edhe ti paguajn online brenda sistemit.',
    'rows' => 'rreshta',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Subdomain',
    'provide_name_or_email' => 'Ju lutem vendosni një emër kontakti ose email',
    'charts_and_reports' => 'Grafikone & Raporte',
    'chart' => 'Grafik',
    'report' => 'Raport',
    'group_by' => 'Grupo sipas',
    'paid' => 'Paguar',
    'enable_report' => 'Raport',
    'enable_chart' => 'Grafik',
    'totals' => 'Totale',
    'run' => 'Fillo',
    'export' => 'Export',
    'documentation' => 'Dokumentim',
    'zapier' => 'Zapier',
    'recurring' => 'Përsëristshme',
    'last_invoice_sent' => 'Fatura e fundit është dërguar më :date',
    'processed_updates' => 'Perditesimi ka përfunduar me sukses',
    'tasks' => 'Detyrat',
    'new_task' => 'Detyrë e re',
    'start_time' => 'Koha e fillimit',
    'created_task' => 'Detyra u krijua me sukses',
    'updated_task' => 'Detyra është perditesuar me sukses',
    'edit_task' => 'Edito Detyrën',
    'clone_task' => 'Clone Task',
    'archive_task' => 'Arkivo Detyrën',
    'restore_task' => 'Rikthe Detyrën',
    'delete_task' => 'Fshi Detyrën',
    'stop_task' => 'Ndalo Detyrën',
    'time' => 'Koha',
    'start' => 'Fillo',
    'stop' => 'Ndalo',
    'now' => 'Tash',
    'timer' => 'Kohëmatësi',
    'manual' => 'Manual',
    'date_and_time' => 'Data & Koha',
    'second' => 'Sekond',
    'seconds' => 'Sekonda',
    'minute' => 'Minut',
    'minutes' => 'Minuta',
    'hour' => 'Ore',
    'hours' => 'Ore',
    'task_details' => 'Detajet e Detyrës',
    'duration' => 'Kohëzgjatja',
    'time_log' => 'Time Log',
    'end_time' => 'Koha e përfundimit',
    'end' => 'Përfundim',
    'invoiced' => 'Faturuar',
    'logged' => 'Regjistruar',
    'running' => 'Duke ndodhur',
    'task_error_multiple_clients' => 'Detyrat nuk mund t\'i caktohen klientëve të ndryshëm',
    'task_error_running' => 'Ju lutem ndaloni së pari detyrën',
    'task_error_invoiced' => 'Detyra tashmë është faturuar',
    'restored_task' => 'Detyra është rikthyer me sukses',
    'archived_task' => 'Detyra është arkivuar me sukses',
    'archived_tasks' => ':count detyra janë arkivuar me sukses',
    'deleted_task' => 'Detyra është fshirë me sukses',
    'deleted_tasks' => ':count detyra janë fshirë me sukses',
    'create_task' => 'Krijo Detyrë',
    'stopped_task' => 'Detyra është ndaluar me sukses',
    'invoice_task' => 'Faturo detyrën',
    'invoice_labels' => 'Etiketat e Faturës',
    'prefix' => 'Prefiks',
    'counter' => 'Numrues',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link për t\'u regjistruar në Dwolla',
    'partial_value' => 'Duhet të jetë më shumë se zero dhe më pak se totali',
    'more_actions' => 'Më shumë veprime',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Ndërro versionin tash!',
    'pro_plan_feature1' => 'Krijo Klient të pa kufizuar',
    'pro_plan_feature2' => 'Qasje në 10 dizajne të bukura të faturave',
    'pro_plan_feature3' => 'URL e ndryshme - "BrendiJuaj.invoiceNinja.com"',
    'pro_plan_feature4' => 'Largoni "Krijuar nga Invoice Ninja"',
    'pro_plan_feature5' => 'Qasje nga shumë-përdorues & Përcjellje e aktiviteteve',
    'pro_plan_feature6' => 'Krijoni Oferta & Pro-Faktura',
    'pro_plan_feature7' => 'Fusha të ndryshueshme të faturës',
    'pro_plan_feature8' => 'Opsion për të dërguar Faturën PDF me email tek klienti',
    'resume' => 'Vazhdo',
    'break_duration' => 'Pushim',
    'edit_details' => 'Edito Detajet',
    'work' => 'Punë',
    'timezone_unset' => 'Ju lutem :link për të rregulluar zonën tuaj kohore',
    'click_here' => 'kliko këtu',
    'email_receipt' => 'Dërgo fletëpagesën tek klienti me email',
    'created_payment_emailed_client' => 'Pagesa ështv krijuar me sukses dhe i është dërguar me email klientit',
    'add_company' => 'Shto Kompani',
    'untitled' => 'Pa Titull',
    'new_company' => 'Kompani e re',
    'associated_accounts' => 'Llogaritë janë lidhur me sukses',
    'unlinked_account' => 'Llogaritë jan zgjidhur me sukses',
    'login' => 'Identifikohu',
    'or' => 'ose',
    'email_error' => 'Ka pasur problem me dërgimin e emailit',
    'confirm_recurring_timing' => 'Shënim: emailat dërgohen në fillim të orës.',
    'confirm_recurring_timing_not_sent' => 'Note: invoices are created at the start of the hour.',
    'payment_terms_help' => 'Sets the default <b>invoice due date</b>',
    'unlink_account' => 'Zgjidh Llogarinë',
    'unlink' => 'Zgjidh',
    'show_address' => 'Shfaq Adresën',
    'show_address_help' => 'Kërkohet që klienti të vendos adresën e faturimit',
    'update_address' => 'Perditeso Adresën',
    'update_address_help' => 'Perditeso adresën e klientit me detajet e ofruara',
    'times' => 'Kohët',
    'set_now' => 'Caktoje për tash',
    'dark_mode' => 'Modeli i errët',
    'dark_mode_help' => 'Use a dark background for the sidebars',
    'add_to_invoice' => 'Shto në faturën :invoice',
    'create_new_invoice' => 'Krijo faturë të re',
    'task_errors' => 'Ju lutem korrigjoni kohët e vendosura mbi njëra-tjetrën',
    'from' => 'Nga',
    'to' => 'Për',
    'font_size' => 'Madhësia e fontit',
    'primary_color' => 'Ngjyra kryesore',
    'secondary_color' => 'Ngjyra dytësore',
    'customize_design' => 'Ndrysho dizajnin',
    'content' => 'Përmbajta',
    'styles' => 'Stilet',
    'defaults' => 'Të paracaktuara',
    'margins' => 'Margjinat',
    'header' => 'Header',
    'footer' => 'Footer',
    'custom' => 'E ndryshueshme',
    'invoice_to' => 'Fatura për',
    'invoice_no' => 'Fatura Nr.',
    'quote_no' => 'Nr. Ofertes',
    'recent_payments' => 'Pagesat e fundit',
    'outstanding' => 'Pa paguar1',
    'manage_companies' => 'Menaxho kompanitë',
    'total_revenue' => 'Totali i Qarkullimit',
    'current_user' => 'Përdoruesi i tashëm',
    'new_recurring_invoice' => 'Faturë e re e përsëritshme',
    'recurring_invoice' => 'Faturë e përsëritshme',
    'new_recurring_quote' => 'New Recurring Quote',
    'recurring_quote' => 'Recurring Quote',
    'recurring_too_soon' => 'Është herët të krijoni faturën e përsëritshme, është e caktuar për :date',
    'created_by_invoice' => 'Krijuar nga :invoice',
    'primary_user' => 'Përdoruesi kryesor',
    'help' => 'Ndihmë',
    'customize_help' => '<p>We use :pdfmake_link to define the invoice designs declaratively. The pdfmake :playground_link provides a great way to see the library in action.</p>
                        <p>If you need help figuring something out post a question to our :forum_link with the design you\'re using.</p>',
    'playground' => 'playground',
    'support_forum' => 'support forum',
    'invoice_due_date' => 'Deri më datë',
    'quote_due_date' => 'Valide deri',
    'valid_until' => 'Valide deri',
    'reset_terms' => 'Reseto kushtet',
    'reset_footer' => 'Reseto footer',
    'invoice_sent' => ':count invoice sent',
    'invoices_sent' => ':count invoices sent',
    'status_draft' => 'Draft',
    'status_sent' => 'Dërguar',
    'status_viewed' => 'Shikuar',
    'status_partial' => 'Pjesërisht',
    'status_paid' => 'Paguar',
    'status_unpaid' => 'Unpaid',
    'status_all' => 'All',
    'show_line_item_tax' => 'Shfaq <b>line item taxes inline</b>',
    'iframe_url' => 'Webfaqja',
    'iframe_url_help1' => 'Kopjoni këtë kod në një faqe në webfaqen tuaj.',
    'iframe_url_help2' => 'Ju mund ta testoni këtëopsion duke klikuar "Shikoni si pranues" në faturë.',
    'auto_bill' => 'Faturo Automatikisht',
    'military_time' => 'Koha 24 orëshe',
    'last_sent' => 'E dërguar për herë të fundit',
    'reminder_emails' => 'Email përkujtues',
    'quote_reminder_emails' => 'Quote Reminder Emails',
    'templates_and_reminders' => 'Shabllonet & Përkujtueset',
    'subject' => 'Tema',
    'body' => 'Përmbajtja',
    'first_reminder' => 'Përkujtuesi i parë',
    'second_reminder' => 'Përkujtuesi i dytë',
    'third_reminder' => 'Përkujtuesi i tretë',
    'num_days_reminder' => 'Ditë pas afatit të pagesës',
    'reminder_subject' => 'Përkujtues: Fatura :invoice nga :account',
    'reset' => 'Reseto',
    'invoice_not_found' => 'Fatura e kërkuar nuk është në dispozicion',
    'referral_program' => 'Programi i referimit',
    'referral_code' => 'URL për referi',
    'last_sent_on' => 'E dërguar për herë të fundit :date',
    'page_expire' => 'Kjo faqe do të mbyllet shpejtë. :click_here për të vazhduar punën',
    'upcoming_quotes' => 'Ofertat e ardhshme',
    'expired_quotes' => 'Ofertat e skaduara',
    'sign_up_using' => 'Regjistrohu duke përdorur',
    'invalid_credentials' => 'Këto kredenciale nuk përputhen me të dhënat tona',
    'show_all_options' => 'Shfaq të gjitha opsionet',
    'user_details' => 'Detajet e përdoruesit',
    'oneclick_login' => 'Connected Account',
    'disable' => 'Ç\'aktivizo',
    'invoice_quote_number' => 'Numrat e faturave dhe ofertave',
    'invoice_charges' => 'Invoice Surcharges',
    'notification_invoice_bounced' => 'Nuk kishim mundësi të dërgonim faturën :invoice tek :contact',
    'notification_invoice_bounced_subject' => 'Nuk mund të dërgohet fatura :invoice',
    'notification_quote_bounced' => 'Nuk kishim mundësi të dërgonim Ofertën :invoice tek :contact',
    'notification_quote_bounced_subject' => 'Nuk mund të dërgohet Oferta :invoice',
    'custom_invoice_link' => 'Linku për faturë',
    'total_invoiced' => 'Total të faturuara',
    'open_balance' => 'Bilanci i hapur',
    'verify_email' => 'Ju lutem vizitoni linkun në email adresën tuaj për të verifikuar adresën tuaj.',
    'basic_settings' => 'Rregullimet bazike',
    'pro' => 'Pro',
    'gateways' => 'Kanalet e Pagesave',
    'next_send_on' => 'Dërgo të ardhshmën :date',
    'no_longer_running' => 'Kjo faturë nuk është programuar të vazhdojë',
    'general_settings' => 'Rregullimet Gjenerale',
    'customize' => 'Ndrysho',
    'oneclick_login_help' => 'Lidheni një llogari të identifikoheni pa fjalëkalim',
    'referral_code_help' => 'Fitoni para duke shpërndarë aplikacionin tonë online',
    'enable_with_stripe' => 'Aktivizo | Kërkohet Stripe',
    'tax_settings' => 'Rregullimet e Taksave',
    'create_tax_rate' => 'Vendos normën e taksës',
    'updated_tax_rate' => 'Norma e taksës është perditesuar me sukses',
    'created_tax_rate' => 'Norma e taksës është krijuar me sukses',
    'edit_tax_rate' => 'Edito normën e taksës',
    'archive_tax_rate' => 'Arkivo normën e taksës',
    'archived_tax_rate' => 'Norma e taksës është arkivuar me sukses',
    'default_tax_rate_id' => 'Norma e paracaktuar e taksave',
    'tax_rate' => 'Norma e taksave',
    'recurring_hour' => 'Ora e përsëritjes',
    'pattern' => 'Modeli',
    'pattern_help_title' => 'Ndihmë për modelin',
    'pattern_help_1' => 'Create custom numbers by specifying a pattern',
    'pattern_help_2' => 'Variablat në dispozicion:',
    'pattern_help_3' => 'Për shembull, :example do të konvertohet në :value',
    'see_options' => 'Shiko opsionet',
    'invoice_counter' => 'Numruesi i faturave',
    'quote_counter' => 'Numruesi i ofertave',
    'type' => 'Shkruaj',
    'activity_1' => ':user ka krijuar klientin :client',
    'activity_2' => ':user ka arkivuar klientin :client',
    'activity_3' => ':user ka fshirë klientin :client',
    'activity_4' => ':user ka krijuar faturën :invoice',
    'activity_5' => ':user ka perditesuar faturën :invoice',
    'activity_6' => ':user emailed invoice :invoice for :client to :contact',
    'activity_7' => ':contact viewed invoice :invoice for :client',
    'activity_8' => ':user ka arkivuar faturën :invoice',
    'activity_9' => ':user ka fshirë faturën :invoice',
    'activity_10' => ':contact entered payment :payment for :payment_amount on invoice :invoice for :client',
    'activity_11' => ':user ka perditesuar pagesën :payment',
    'activity_12' => ':user ka arkivuar pagesën :payment',
    'activity_13' => ':user ka fshirë pagesën :payment',
    'activity_14' => ':user ka shtuar :credit kredit',
    'activity_15' => ':user ka perditesuar :credit kredit',
    'activity_16' => ':user ka arkivuar :credit kredit',
    'activity_17' => ':user ka fshirë:credit kredit',
    'activity_18' => ':user ka krijuar ofertë :quote',
    'activity_19' => ':user ka perditesuar ofertën :quote',
    'activity_20' => ':user emailed quote :quote for :client to :contact',
    'activity_21' => ':contact ka shikuar ofertën :quote',
    'activity_22' => ':user ka arkivuar ofertën :quote',
    'activity_23' => ':user ka fshirë ofertën :quote',
    'activity_24' => ':user ka rikthyer ofertën :quote',
    'activity_25' => ':user ka rikthyer faturën :invoice',
    'activity_26' => ':user ka rikthyer klientin :client',
    'activity_27' => ':user ka rikthyer pagesën :payment',
    'activity_28' => ':user ka rikthyer :credit kredit',
    'activity_29' => ':contact approved quote :quote for :client',
    'activity_30' => ':user created vendor :vendor',
    'activity_31' => ':user archived vendor :vendor',
    'activity_32' => ':user deleted vendor :vendor',
    'activity_33' => ':user restored vendor :vendor',
    'activity_34' => ':user ka krijuar shpeznim :expense',
    'activity_35' => ':user archived expense :expense',
    'activity_36' => ':user deleted expense :expense',
    'activity_37' => ':user restored expense :expense',
    'activity_42' => ':user created task :task',
    'activity_43' => ':user updated task :task',
    'activity_44' => ':user archived task :task',
    'activity_45' => ':user deleted task :task',
    'activity_46' => ':user restored task :task',
    'activity_47' => ':user updated expense :expense',
    'activity_48' => ':user updated ticket :ticket',
    'activity_49' => ':user closed ticket :ticket',
    'activity_50' => ':user merged ticket :ticket',
    'activity_51' => ':user split ticket :ticket',
    'activity_52' => ':contact opened ticket :ticket',
    'activity_53' => ':contact reopened ticket :ticket',
    'activity_54' => ':user reopened ticket :ticket',
    'activity_55' => ':contact replied ticket :ticket',
    'activity_56' => ':user viewed ticket :ticket',

    'payment' => 'Pagesa',
    'system' => 'Sistem',
    'signature' => 'Nënshkrimi i emailit',
    'default_messages' => 'Mesazh i paracaktuar',
    'quote_terms' => 'Kushtet e Ofertave',
    'default_quote_terms' => 'Kushtet e paracaktuara të ofertave',
    'default_invoice_terms' => 'Kushtet e paracektuara të faturës',
    'default_invoice_footer' => 'Footer i paracaktuar i faturës',
    'quote_footer' => 'Footer i Ofertës',
    'free' => 'Falas',
    'quote_is_approved' => 'Successfully approved',
    'apply_credit' => 'Apliko kreditin',
    'system_settings' => 'Rregullimi i sistemit',
    'archive_token' => 'Arkivo tokenin',
    'archived_token' => 'Tokeni është arkivuar me sukses',
    'archive_user' => 'Arkivo përdoruesin',
    'archived_user' => 'Përdoruesi është arkivuar me sukses',
    'archive_account_gateway' => 'Delete Gateway',
    'archived_account_gateway' => 'Kanali i pagesës është arkivuar me sukses',
    'archive_recurring_invoice' => 'Arkivo faturën e përsëritshme',
    'archived_recurring_invoice' => 'Faturat e përsëritshme janë arkivuar me sukses',
    'delete_recurring_invoice' => 'Fshi faturat e përsëritshme',
    'deleted_recurring_invoice' => 'Faturat e përsëritshme janë fshirë  me sukses',
    'restore_recurring_invoice' => 'Rikthe faturat e përsëritshme',
    'restored_recurring_invoice' => 'Faturat e përsëritshme janë rikthyer me sukses',
    'archive_recurring_quote' => 'Archive Recurring Quote',
    'archived_recurring_quote' => 'Successfully archived recurring quote',
    'delete_recurring_quote' => 'Delete Recurring Quote',
    'deleted_recurring_quote' => 'Successfully deleted recurring quote',
    'restore_recurring_quote' => 'Restore Recurring Quote',
    'restored_recurring_quote' => 'Successfully restored recurring quote',
    'archived' => 'Arkivuar',
    'untitled_account' => 'Kompani e paemruar',
    'before' => 'Përpara',
    'after' => 'Pas',
    'reset_terms_help' => 'Reseto në kushtet e llogarisë',
    'reset_footer_help' => 'Reseto footer për llogarinë e paracaktuar',
    'export_data' => 'Eksporto të dhënat',
    'user' => 'Përdorues',
    'country' => 'Shteti',
    'include' => 'Përfshi',
    'logo_too_large' => 'Logo juaj është :size për performansë më të mirë në PDF ju sugjerojmë që të ngarkoni fajll më të vogël se 200KB',
    'import_freshbooks' => 'Importo nga FreshBooks',
    'import_data' => 'Importo të dhëna',
    'source' => 'Burimi',
    'csv' => 'CSV',
    'client_file' => 'Fajlli i klientit',
    'invoice_file' => 'Fajlli i faturës',
    'task_file' => 'Fajlli i detyrave',
    'no_mapper' => 'Nuk ka vendodhje valide për fajll',
    'invalid_csv_header' => 'CSV Header invalid',
    'client_portal' => 'Portali i klientit',
    'admin' => 'Admin',
    'disabled' => 'E ç\'aktivizuar',
    'show_archived_users' => 'Shfaq përdoruesit e arkivuar',
    'notes' => 'Shënime',
    'invoice_will_create' => 'invoice will be created',
    'invoices_will_create' => 'Faturat do të krijohen',
    'failed_to_import' => 'Të dhënat në vazhdim nuk kanë mundur të importohen, ato ose tashmë ekzistojnë ose ju mungojnë fushat e kërkuara.',
    'publishable_key' => 'Çelësi i publikueshëm',
    'secret_key' => 'Çelësi sekret',
    'missing_publishable_key' => 'Shfaqni çelësin e publikueshëm të Stripe për proces të përmirësuar të pagesës',
    'email_design' => 'Dizajno emailin',
    'due_by' => 'Deri më :date',
    'enable_email_markup' => 'Aktivizo Markimin',
    'enable_email_markup_help' => 'Bëjeni më të lehtë për klientët tuaj të realizojnë pagesat duke vendosur schema.org markimin në emailat tuaj.',
    'template_help_title' => 'Ndihma për shabllonë',
    'template_help_1' => 'Variablat në dispozicion:',
    'email_design_id' => 'Stili i emailit',
    'email_design_help' => 'Make your emails look more professional with HTML layouts.',
    'plain' => 'E thjeshtë',
    'light' => 'E lehtë',
    'dark' => 'E mbylltë',
    'industry_help' => 'Përdoret për të realizuar krahasime ndaj kompanive mesatere me numër puntorësh të ngjashëm.',
    'subdomain_help' => 'Set the subdomain or display the invoice on your own website.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Caktoni një prefiks ose ndonjë shabllon të caktuar për të dinamizuar numrin e faturave.',
    'quote_number_help' => 'Caktoni një prefiks ose ndonjë shabllon të caktuar për të dinamizuar numrin e ofertave.',
    'custom_client_fields_helps' => 'Add a field when creating a client and optionally display the label and value on the PDF.',
    'custom_account_fields_helps' => 'Shtoni një etiketë dhe vlerë tek detajet e kompanisë në PDF.',
    'custom_invoice_fields_helps' => 'Add a field when creating an invoice and optionally display the label and value on the PDF.',
    'custom_invoice_charges_helps' => 'Shto një fushë kur të krijoni faturë dhe përfshijeni këtë kosto në nëntotalin e faturës.',
    'token_expired' => 'Validimi i tokenit ka skaduar. Ju lutem provoni përsëri.',
    'invoice_link' => 'Linku i faturës',
    'button_confirmation_message' => 'Kliko për të konfirmuar email adresën tuaj.',
    'confirm' => 'Konfirmo',
    'email_preferences' => 'Preferencat e emailit',
    'created_invoices' => 'Janë krijuar me sukses :count fatura',
    'next_invoice_number' => 'Numri i ardhshëm i faturës është :number.',
    'next_quote_number' => 'Numri i ardhshëm i ofertës është :number.',
    'days_before' => 'days before the',
    'days_after' => 'days after the',
    'field_due_date' => 'deri më datë',
    'field_invoice_date' => 'Data e faturës',
    'schedule' => 'Orari',
    'email_designs' => 'Dizajnet e emailit',
    'assigned_when_sent' => 'E caktuar kur është dërguar',
    'white_label_purchase_link' => 'Bleni licensën white label',
    'expense' => 'Shpenzimet',
    'expenses' => 'Shpenzimet',
    'new_expense' => 'Enter Expense',
    'enter_expense' => 'Shto shpenzim',
    'vendors' => 'Kompanitë',
    'new_vendor' => 'Kompani e re',
    'payment_terms_net' => 'Net',
    'vendor' => 'Kompani',
    'edit_vendor' => 'Edito kompaninë',
    'archive_vendor' => 'Arkivo kompaninë',
    'delete_vendor' => 'Fshi kompaninë',
    'view_vendor' => 'Shiko kompaninë',
    'deleted_expense' => 'Shpenzimi është fshirë me sukses',
    'archived_expense' => 'Shpenzimi është arkivuar me sukses',
    'deleted_expenses' => 'Shpenzimet janë fshirë me sukses',
    'archived_expenses' => 'Shpenzimet janë arkivuar me sukses',
    'expense_amount' => 'Shuma e shpenzimeve',
    'expense_balance' => 'Bilanci i shpenzimeve',
    'expense_date' => 'Data e shpenzimit',
    'expense_should_be_invoiced' => 'A duhet ky shpenzim të faturohet?',
    'public_notes' => 'Shënime publike',
    'invoice_amount' => 'Shuma e faturës',
    'exchange_rate' => 'Kursi i këmbimit',
    'yes' => 'Po',
    'no' => 'Jo',
    'should_be_invoiced' => 'Duhet të faturohet',
    'view_expense' => 'Shiko # :expense të shpenzimit',
    'edit_expense' => 'Edito shpenzimi',
    'archive_expense' => 'Arkivo shpenzimin',
    'delete_expense' => 'Fshi shpenzimin',
    'view_expense_num' => 'Shpenzimi # :expense',
    'updated_expense' => 'Shpenzimi është perditesuar me sukses',
    'created_expense' => 'Shpenzimi është krijuar me sukses',
    'enter_expense' => 'Shto shpenzim',
    'view' => 'Shiko',
    'restore_expense' => 'Rikthe shpenzimet',
    'invoice_expense' => 'Faturë shpenzimesh',
    'expense_error_multiple_clients' => 'Shpenzimet nuk mund t\'i kalojnë klientit tjetër',
    'expense_error_invoiced' => 'Shpenzimet tashmë janë fatururar',
    'convert_currency' => 'Konverto valutën',
    'num_days' => 'Number of Days',
    'create_payment_term' => 'Krijo kushtet e pagesës',
    'edit_payment_terms' => 'Edito kushtet e pagesës',
    'edit_payment_term' => 'Edito kushtet e pagesës',
    'archive_payment_term' => 'Arkivo kushtet e pagesës',
    'recurring_due_dates' => 'Datat e përsëritjes së faturës',
    'recurring_due_date_help' => '<p>Automatikisht caktohet data e pagesës së faturës.</p>
        <p>Faturat e cilklit mujor ose vjetor do të caktohen për muajin e ardhshëm. Faturat e caktuara në datat 29 dhe 30 që nuk i kanë këto ditë do të caktohen në ditën e fundit të atij muaji.</p>
        <p>Faturat e krijuara në ciklin javor të caktuara për pagesë në ditë të caktuara do të caktohen nga java e ardhshme.</p>
        <p>Për shembull:</p>
        <ul>
          <li>Sot është data 15, data e pagesës është 1 e muajit. Data e pagesës së ardhshme do të jetë data 1 e muajit të ardhshëm.</li>
          <li>TSot është data 15, data e pagesës është dita e fundit e muajit. Data për pagesë do të jetë dita e fundit e këtij muaji.
</li>
          <li>Sot është data 15, data e pagesës është 15 të muajit. Data për pagesë do të jetë 15 e muajit  <strong>tjetër</strong>.
</li>
          <li>Sot është e premte, data e pagesës është e premte e parë. Data e pagesës do të jetë e premtja tjetër, jo sot..
</li>
        </ul>',
    'due' => 'Deri më',
    'next_due_on' => 'Deri:',
    'use_client_terms' => 'Përdor kushtet e klientit',
    'day_of_month' => ':ordinal ditë e muajit',
    'last_day_of_month' => 'Dita e fundit e muajit',
    'day_of_week_after' => ':ordinal :day pas',
    'sunday' => 'E diel',
    'monday' => 'E hënë',
    'tuesday' => 'E marte',
    'wednesday' => 'E mërkure',
    'thursday' => 'E enjëte',
    'friday' => 'E premte',
    'saturday' => 'E shtune',
    'header_font_id' => 'Fonti i Header',
    'body_font_id' => 'Fonti i tekstit',
    'color_font_help' => 'Shënim: Ngjyra themelore dhe fontet përdoren gjithashtu në portalin e klientit dhe dizajnin e emailit',
    'live_preview' => 'Live parashikim',
    'invalid_mail_config' => 'Nuk është dërguar emaili, ju lutem shikoni rregullimet a janë korrekte.',
    'invoice_message_button' => 'Për të shikura faturën tuaj për :amount, klikoni butonin më poshtë.',
    'quote_message_button' => 'Për të shikuar ofertën për :amount, klikoni butonin më poshtë.',
    'payment_message_button' => 'Ju faleminderit për pagesën prej :amount.',
    'payment_type_direct_debit' => 'Direct Debit',
    'bank_accounts' => 'Kredit Kartat & Bankat',
    'add_bank_account' => 'Shto llogarinë bankare',
    'setup_account' => 'Rregullo llogarinë',
    'import_expenses' => 'Importo shpenzimet',
    'bank_id' => 'Banka',
    'integration_type' => 'Lloji i ntegrimit',
    'updated_bank_account' => 'Llogaria bankare është perditesuar me sukses',
    'edit_bank_account' => 'Edito llogarinë bankare',
    'archive_bank_account' => 'Arkivo llogarinë bankare',
    'archived_bank_account' => 'Llogaria bankare është azhurnuar me sukses',
    'created_bank_account' => 'Llogaria bankare është krijuar me sukses',
    'validate_bank_account' => 'Valido llogarinë bankare',
    'bank_password_help' => 'Shënime: fjalëkalimi juaj transmetohet sigurtë dhe asnjëherë nuk ruhet në sererët tonë.',
    'bank_password_warning' => 'Vërejtje: fjalëkalimi juaj duhet të transmetohet si tekst i thjeshtë, konsideroni të aktivizoni HTTPS.',
    'username' => 'identifikimi',
    'account_number' => 'Numri i llogarisë',
    'account_name' => 'Emri i llogarisë',
    'bank_account_error' => 'Failed to retrieve account details, please check your credentials.',
    'status_approved' => 'Aprovuar',
    'quote_settings' => 'Rregullimi i Ofertës',
    'auto_convert_quote' => 'Auto Convert',
    'auto_convert_quote_help' => 'Automatikisht konverto ofertën në faturë kur pranohet nga klienti.',
    'validate' => 'Valido',
    'info' => 'Info',
    'imported_expenses' => 'Janë krijuar me sukses :count_vendors jinoabu dhe :count_expenses shpenzime',
    'iframe_url_help3' => 'Shënim: Nëse planifikoni të pranoni detajet e kredit kartave ne ju rekomandojmë të aktivizoni HTTPS në webfaqen tuaj.',
    'expense_error_multiple_currencies' => 'Shpenzimet nuk mund të kenë valuta të ndryshme.',
    'expense_error_mismatch_currencies' => 'Valuta e klientit nuk përputhet me valutën e shpenzimeve.',
    'trello_roadmap' => 'Trello Rrugëtimi',
    'header_footer' => 'Header/Footer',
    'first_page' => 'Faqja e parë',
    'all_pages' => 'Të gjitha faqet',
    'last_page' => 'Faqja e fundit',
    'all_pages_header' => 'Shfaqe Header',
    'all_pages_footer' => 'Shfaqe Footer',
    'invoice_currency' => 'Valuta e Faturës',
    'enable_https' => 'Ju rekomandojmë të përdorni HTTPS për të pranuar detajet e kredit kartave online.',
    'quote_issued_to' => 'Oferta i është lëshuar',
    'show_currency_code' => 'Kodi i valutës',
    'free_year_message' => 'Your account has been upgraded to the pro plan for one year at no cost.',
    'trial_message' => 'Llogaria juaj do të pranojë një periudhë testuese dyjavore të Pro planit që ofrojmë.',
    'trial_footer' => 'Your free pro plan trial lasts :count more days, :link to upgrade now.',
    'trial_footer_last_day' => 'This is the last day of your free pro plan trial, :link to upgrade now.',
    'trial_call_to_action' => 'Filloni periudhën provuese',
    'trial_success' => 'Periudha provuese dyjavore për pro planin është aktivizuar me sukses',
    'overdue' => 'E vonuar',


    'white_label_text' => 'Bli nje license vjecare me cmimin $:price per te hequr logot dhe tekstet e Invoice Ninja nga fatura dhe portali i klientit. ',
    'user_email_footer' => 'Për të ndryshuar lajmërimet tuaja me email vizitoni :link',
    'reset_password_footer' => 'Nëse nuk keni kërkuar resetimin e fjalëkalimit ju lutem na shkruani në emailin tonë : :email',
    'limit_users' => 'Na falni, kjo tejkalon limitin e :limit përdoruesve',
    'more_designs_self_host_header' => 'Merrni 6 dizajne tjera të faturave për vetëm $:price',
    'old_browser' => 'Please use a :link',
    'newer_browser' => 'newer browser',
    'white_label_custom_css' => ':link për $:price për të ndryshuar stilin dhe përkrahur projektin tonë.',
    'bank_accounts_help' => 'Connect a bank account to automatically import expenses and create vendors. Supports American Express and :link.',
    'us_banks' => '400+ US banks',

    'pro_plan_remove_logo' => ':link për të larguar Invoice Ninja logo duke iu bashkangjitur Pro Planit',
    'pro_plan_remove_logo_link' => 'Kliko këtu',
    'invitation_status_sent' => 'Sent',
    'invitation_status_opened' => 'Opened',
    'invitation_status_viewed' => 'Viewed',
    'email_error_inactive_client' => 'Emailat nuk mund t\'i dërgohen klientëve joaktiv',
    'email_error_inactive_contact' => 'Emailat nuk mund t\'i dërgohen kontakteve joaktiv',
    'email_error_inactive_invoice' => 'Emailat nuk mund t\'i dërgohen faturave joaktive',
    'email_error_inactive_proposal' => 'Emails can not be sent to inactive proposals',
    'email_error_user_unregistered' => 'Ju lutem regjistroni llogarinë tuaj të dërgoni email',
    'email_error_user_unconfirmed' => 'Ju lutem konfirmoni llogarinë tuaj të dërgoni email',
    'email_error_invalid_contact_email' => 'Emaili i kontaktit i pa saktë',

    'navigation' => 'Navigimi',
    'list_invoices' => 'Listo faturat',
    'list_clients' => 'Listo klientët',
    'list_quotes' => 'Listo ofertat',
    'list_tasks' => 'Listo detyrat',
    'list_expenses' => 'Listo shpenzimet',
    'list_recurring_invoices' => 'Listo Faturat e përsëritshme',
    'list_payments' => 'Listo pagesat',
    'list_credits' => 'Listo kreditë',
    'tax_name' => 'Emri i taksës',
    'report_settings' => 'Rregullimi i raporteve',
    'search_hotkey' => 'shkurtesa është /',

    'new_user' => 'Përdorues i ri',
    'new_product' => 'Produkt i ri',
    'new_tax_rate' => 'Normë e re e taksave',
    'invoiced_amount' => 'Shuma e faturuar',
    'invoice_item_fields' => '
Fushat e njësive në faturë',
    'custom_invoice_item_fields_help' => 'Shtoni një fushë ë kur të krijoni faturë dhe etiketa me vlerë të shfaqen në PDF.',
    'recurring_invoice_number' => 'Recurring Number',
    'recurring_invoice_number_prefix_help' => 'Specify a prefix to be added to the invoice number for recurring invoices.',

    // Client Passwords
    'enable_portal_password' => 'Password Protect Invoices',
    'enable_portal_password_help' => 'Ju mundëson të vendosni fjalëkalim për secilin kontakt. Nëse vendoset fjalëkalimi, kontakti duhet të vendos fjalëkalimin para se t\'i sheh faturat.',
    'send_portal_password' => 'Generate Automatically',
    'send_portal_password_help' => 'Nëse nuk caktoni fjalëkalim, do të krijohet një dhe do t\'ju dërgohet me faturën e parë.',

    'expired' => 'Skaduar',
    'invalid_card_number' => 'Numri i kredit kartës nuk është valid.',
    'invalid_expiry' => 'Data e skadimit nuk është valide.',
    'invalid_cvv' => 'CVV nuk është valid.',
    'cost' => 'Kosto',
    'create_invoice_for_sample' => 'Shënim: krijoni faturën e parë këtu për ta parashikuar.',

    // User Permissions
    'owner' => 'Pronari',
    'administrator' => 'Administrator',
    'administrator_help' => 'Lejon përdoruesit të menaxhoj përdoruesit, të ndryshojë rregullimet dhe të modifikojë të gjitha shënimet.',
    'user_create_all' => 'Krijo klient, fatura, etj.',
    'user_view_all' => 'Shiko të gjithë klientët, faturat, etj.',
    'user_edit_all' => 'Edito të gjithë klientët, faturat, etj.',
    'gateway_help_20' => ':link për tu regjistruar për Sage Pay.',
    'gateway_help_21' => ':link për t\'u regjistruar në Sage Pay.',
    'partial_due' => 'Paguar pjesërisht',
    'restore_vendor' => 'Rikthe kompaninë',
    'restored_vendor' => 'Kompania u rikthye me sukses',
    'restored_expense' => 'Shpenzimet janë rikthyer me sukses',
    'permissions' => 'Lejet',
    'create_all_help' => 'Lejo përdoruesit të krijojnë dhe modifikojnë shënime',
    'view_all_help' => 'Lejo përdoruesit të shohin të dhëna që nuk i kanë krijuar',
    'edit_all_help' => 'Lejo përdoruesit të modifikojnë shënimet që nuk i kanë krijuar',
    'view_payment' => 'Shiko pagesën',

    'january' => 'Janar',
    'february' => 'Shkurt',
    'march' => 'Mars',
    'april' => 'Prill',
    'may' => 'Maj',
    'june' => 'Qershor',
    'july' => 'Korrik',
    'august' => 'Gusht',
    'september' => 'Shtator',
    'october' => 'Tetor',
    'november' => 'Nëntor',
    'december' => 'Dhjetor',

    // Documents
    'documents_header' => 'Dokumente:',
    'email_documents_header' => 'Dokumente:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Quote Documents',
    'invoice_documents' => 'Invoice Documents',
    'expense_documents' => 'Expense Documents',
    'invoice_embed_documents' => 'Dokumentet e lidhura',
    'invoice_embed_documents_help' => 'Vendos fotografinë në faturë.',
    'document_email_attachment' => 'Bashkangjit dokumente',
    'ubl_email_attachment' => 'Attach UBL',
    'download_documents' => 'Shkarko dokumentet (:size)',
    'documents_from_expenses' => 'Nga shpenzimet:',
    'dropzone_default_message' => 'Gjuaj fajllin ose kliko për ta ngarkuar',
    'dropzone_default_message_disabled' => 'Uploads disabled',
    'dropzone_fallback_message' => 'Shfletuesi juaj nuk përkrahë gjuajtjen e fajllave.',
    'dropzone_fallback_text' => 'Ju lutem përdorni formën e mëposhtme për të ngarkuar fajllat tuaj.',
    'dropzone_file_too_big' => 'Fajlli është shumë i madh ({{filesize}}MiB). Madhësia maksimale: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Nuk mund të ngarkoni këtë lloj fajlli',
    'dropzone_response_error' => 'Serveri është përgjigjur me kodin {{statusCode}}.',
    'dropzone_cancel_upload' => 'Anulo ngarkimin',
    'dropzone_cancel_upload_confirmation' => 'A jeni i sigurt që doni të anuloni këtë ngarkim?',
    'dropzone_remove_file' => 'Largo fajllin',
    'documents' => 'Dokumente',
    'document_date' => 'Data e dokumentit',
    'document_size' => 'Madhësia',

    'enable_client_portal' => 'Portali i klientit',
    'enable_client_portal_help' => 'Shfaq/fsheh portalin e klientit.',
    'enable_client_portal_dashboard' => 'Paneli',
    'enable_client_portal_dashboard_help' => 'Shfaq/fsheh panelin në portalin e klientit.',

    // Plans
    'account_management' => 'Menaxhimi i llogarive',
    'plan_status' => 'Statusi i planit',

    'plan_upgrade' => 'Ndërro versionin',
    'plan_change' => 'Ndrysho planin',
    'pending_change_to' => 'Ndryshohet në',
    'plan_changes_to' => ':plan më :datë',
    'plan_term_changes_to' => ':plan (:term) më :date',
    'cancel_plan_change' => 'Anulo ndryshimin',
    'plan' => 'Plan',
    'expires' => 'Skadon',
    'renews' => 'Ripërtrij',
    'plan_expired' => ':plan Plani ka skaduar',
    'trial_expired' => ':plan Plani provues ka mbaruar',
    'never' => 'Asnjëherë',
    'plan_free' => 'Falas',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'I hostuar vetë (White labaled)',
    'plan_free_self_hosted' => 'I vetë-hostuar (Falas)',
    'plan_trial' => 'Provues',
    'plan_term' => 'Kusht',
    'plan_term_monthly' => 'Mujor',
    'plan_term_yearly' => 'Vjetor',
    'plan_term_month' => 'Muaj',
    'plan_term_year' => 'Vit',
    'plan_price_monthly' => '$:price/Muaj',
    'plan_price_yearly' => '$:price/Vit',
    'updated_plan' => 'Plani i softuerit është perditesuar',
    'plan_paid' => 'Kushtet kanë filluar',
    'plan_started' => 'Plani ka filluar',
    'plan_expires' => 'Plani skadon',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'Regjistrimi një vjeçar në Invoice Ninja Pro Plan.',
    'pro_plan_month_description' => 'Regjistrim një mujor në Invoice Ninja Pro Plan.',
    'enterprise_plan_product' => 'Plani Enterprise',
    'enterprise_plan_year_description' => 'Regjistrimi një vjeçar në Invoice Ninja Enterprise Plan.',
    'enterprise_plan_month_description' => 'Regjistrimi një mujor në Invoice Ninja Enterprise Plan.',
    'plan_credit_product' => 'Kredit',
    'plan_credit_description' => 'Kredit për kohën e pa përdorur',
    'plan_pending_monthly' => 'Do të kaloj në baza mujore më :date',
    'plan_refunded' => 'Rimbursimi është aprovuar.',

    'live_preview' => 'Live parashikim',
    'page_size' => 'Madhësia e faqes',
    'live_preview_disabled' => 'Parashikimi live është çaktivizuar për të përkrahur fontin e selektuar',
    'invoice_number_padding' => 'Mbushje',
    'preview' => 'Parashiko',
    'list_vendors' => 'Listo kompanitë',
    'add_users_not_supported' => 'Kaloni në planin Enterprise për të shtuar përdorues shtesë në llogarinë tuaj.',
    'enterprise_plan_features' => 'Plani Enterprise shton përkrahje për shumë përdorues dhe bashkangjithjen e fajllave, :link për të parë listën e të gjitha veçorive.',
    'return_to_app' => 'Return To App',


    // Payment updates
    'refund_payment' => 'Rimburso pagesën',
    'refund_max' => 'Maksimumi:',
    'refund' => 'Rimburso',
    'are_you_sure_refund' => 'Rimburso pagesën e selektuar?',
    'status_pending' => 'Në pritje',
    'status_completed' => 'E përfunduar',
    'status_failed' => 'Ka dështuar',
    'status_partially_refunded' => 'Rimbursuar pjesërisht',
    'status_partially_refunded_amount' => ':amount janë rimbursuar',
    'status_refunded' => 'Rimbursuar',
    'status_voided' => 'Anuluar',
    'refunded_payment' => 'Pagesë e rimbursuar',
    'activity_39' => ':user cancelled a :payment_amount payment :payment',
    'activity_40' => ':user refunded :adjustment of a :payment_amount payment :payment',
    'card_expiration' => 'Skadon:&nbsp:expires',

    'card_creditcardother' => 'Panjohur',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accept US bank transfers',
    'stripe_ach_help' => 'ACH support must also be enabled in :link.',
    'ach_disabled' => 'Një tjetër kanal pagese tashmë është konfiguruar për direkt debit.',

    'plaid' => 'Plaid',
    'client_id' => 'ID e klientit',
    'secret' => 'Sekret',
    'public_key' => 'Çelësi publik',
    'plaid_optional' => '(opsionale)',
    'plaid_environment_help' => 'When a Stripe test key is given, Plaid\'s development environment (tartan) will be used.',
    'other_providers' => 'Ofrues tjerë',
    'country_not_supported' => 'Ky shtet nuk përkrahet.',
    'invalid_routing_number' => 'Numri nuk është valid.',
    'invalid_account_number' => 'Numri i llogarisë nuk është valid.',
    'account_number_mismatch' => 'Numri i llogarisë nuk përshtatet.',
    'missing_account_holder_type' => 'Ju lutem zgjedhni një llogari individuale ose kompani.',
    'missing_account_holder_name' => 'Ju lutem vendosni emrin e mbajtësit të llogarisë.',
    'routing_number' => 'Numri rrjedhës',
    'confirm_account_number' => 'Konfirmo numrin e llogarisë',
    'individual_account' => 'Llogari individuale',
    'company_account' => 'Llogari e kompanisë',
    'account_holder_name' => 'Emri i mbajtësit të llogarisë',
    'add_account' => 'Shto llogari',
    'payment_methods' => 'Metodat e pagesës',
    'complete_verification' => 'Përfundo Verifikimin',
    'verification_amount1' => 'Shuma 1',
    'verification_amount2' => 'Shuma 2',
    'payment_method_verified' => 'Verifikimi ka përfunduar me sukses',
    'verification_failed' => 'Verifikimi ka dështuar',
    'remove_payment_method' => 'Largo Metodat e pagesës',
    'confirm_remove_payment_method' => 'A jeni të sigurtë që dëshironi të largoni këtë metodë pagese?',
    'remove' => 'Largo',
    'payment_method_removed' => 'Largo metodën e pagesës.',
    'bank_account_verification_help' => 'Ne kemi bërë dy depozita në llogarinë tuaj me përshkrimin "VERIFICATION". Këtyre depozitave do t\'ju duhen 1-2 ditë pune që të paraqiten në pasqyrën tuaj bankare. Ju lutem vendosni shumat më poshtë.',
    'bank_account_verification_next_steps' => 'Ne kemi bërë dy depozita në llogarinë tuaj me përshkrimin "VERIFICATION". Këtyre depozitave do t\'ju duhen 1-2 ditë pune që të paraqiten në pasqyrën tuaj bankare. Ju lutem vendosni shumat më poshtë.
Pasi të keni pranuar shumat, kthehuni në faqen e metodave të pagesës dhe klikoni "Përfundo Verifikimin" afër llogarisë.',
    'unknown_bank' => 'Bankë e panjohur',
    'ach_verification_delay_help' => 'Ju mund të përdorni llogarinë tuaj pas përfundimit të verifikimit. Verifikimi zakonisht zgjat 1-2 ditë pune.',
    'add_credit_card' => 'Shto Kredit kartën',
    'payment_method_added' => 'Është shtuar metoda e pagesës.',
    'use_for_auto_bill' => 'Përdorni për pagesë automatike',
    'used_for_auto_bill' => 'Metodat e pagesave automatike',
    'payment_method_set_as_default' => 'Cakto metodat e pagesës automatike.',
    'activity_41' => ':payment_amount payment (:payment) ka dështuar',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'Ju duhet :link.',
    'stripe_webhook_help_link_text' => 'vendosni këtë URL si pikë fundore e Stripe',
    'gocardless_webhook_help_link_text' => 'add this URL as an endpoint in GoCardless',
    'payment_method_error' => 'Ka ndodhur një gabim gjatë shtimit të metodës së pagesës. Ju lutem provoni përsëri.',
    'notification_invoice_payment_failed_subject' => 'Ka dështuar pagesa për faturën :invoice',
    'notification_invoice_payment_failed' => 'Pagesa e realizuar nga klienti :client për faturën :invoice ka dështuar. Pagesa është shënuar si e dështuar dhe :amount i është shtuar bilancit të klientit.',
    'link_with_plaid' => 'Lidheni llogarinë menjëherë me Plaid',
    'link_manually' => 'Lidhe manualisht',
    'secured_by_plaid' => 'Siguruar nga Plaid',
    'plaid_linked_status' => 'Llogaria juaj bankare në :bank',
    'add_payment_method' => 'Shto metodë pagese',
    'account_holder_type' => 'Lloji i mbajtësit të llogarisë',
    'ach_authorization' => 'E autorizoj :company të përdorë llogarinë time bankare për pagesa në të ardhmen dhe nëse është e nevojshme të kreditohet në mënyrë elektronike llogaria ime për të përmirësuar borxhet. E kuptoj se mundem me anulu këtë autorizim në çdo kohë duke larguar këtë mundësi pagese ose duke kontaktuar në :email.',
    'ach_authorization_required' => 'Ju duhet të aprovoni ACH transaksionet.',
    'off' => 'Ndalur',
    'opt_in' => 'Opt-in',
    'opt_out' => 'Opt-out',
    'always' => 'Gjithmonë',
    'opted_out' => 'Opted out',
    'opted_in' => 'Opted in',
    'manage_auto_bill' => 'Menaxho pagesat automatike',
    'enabled' => 'Aktivizuar',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Aktivizo PayPal pagesat përmse BrainTree',
    'braintree_paypal_disabled_help' => 'Kanali i pagesës PayPal është duke procesuar pagesat PayPal',
    'braintree_paypal_help' => 'Ju gjithashtu duhet :link.',
    'braintree_paypal_help_link_text' => 'lidh PayPal me llogarinë tuaj në BrainTree',
    'token_billing_braintree_paypal' => 'Ruaj detajet e pagesës',
    'add_paypal_account' => 'Shto llogari PayPal',


    'no_payment_method_specified' => 'Nuk është caktuar metoda e pagesës',
    'chart_type' => 'Lloji i grafikonit',
    'format' => 'Format',
    'import_ofx' => 'Importo OFX',
    'ofx_file' => 'OXF Fajll',
    'ofx_parse_failed' => 'Ka dështuar marrja e fajllit OFX',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Regjistrohu në WePay',
    'use_another_provider' => 'Përdor ofrues tjetër',
    'company_name' => 'Emri i kompanisë',
    'wepay_company_name_help' => 'Kjo do të shfaqet në pasqyrën e kredit kartës së klientit',
    'wepay_description_help' => 'Qëllimi i kësaj llogarie.',
    'wepay_tos_agree' => 'Pajtohem me :link.',
    'wepay_tos_link_text' => 'WePay Kushtet e Shërbimit',
    'resend_confirmation_email' => 'Ridërgo konfirmimin me email',
    'manage_account' => 'Menaxho llogaritë',
    'action_required' => 'Kërkohet veprim',
    'finish_setup' => 'Përfundo instalimin',
    'created_wepay_confirmation_required' => 'Ju lutem kontrolloni emailin tuaj dhe konfirmoni email adresën me WePay',
    'switch_to_wepay' => 'Kalo në WePay',
    'switch' => 'Kalo',
    'restore_account_gateway' => 'Rikthe kanalin e pagesës',
    'restored_account_gateway' => 'Kanali i pagesës është rikthyer me sukses',
    'united_states' => 'United States',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Prano Debit Kartë',
    'debit_cards' => 'Debit Kartë',

    'warn_start_date_changed' => 'Fatura e re do të dërgohet në datën e re të fillimit.',
    'warn_start_date_changed_not_sent' => 'The next invoice will be created on the new start date.',
    'original_start_date' => 'Data orgjinale e fillimit',
    'new_start_date' => 'Data e re e filimit',
    'security' => 'Siguria',
    'see_whats_new' => 'Shiko çka ka të re në v:version',
    'wait_for_upload' => 'Ju lutem prisni që dokumenti të ngarkohet me sukses.',
    'upgrade_for_permissions' => 'Kaloni në planin Enterprise për të aktivizuar lejet.',
    'enable_second_tax_rate' => 'Aktivizoni specifikimin e <b>normës së dytë të taksës</b>',
    'payment_file' => 'Fajlli i pagesës',
    'expense_file' => 'Fajlli i shpenzimeve',
    'product_file' => 'Fajlli i produkteve',
    'import_products' => 'Importo produktet',
    'products_will_create' => 'products will be created',
    'product_key' => 'Produkt',
    'created_products' => 'Successfully created/updated :count product(s)',
    'export_help' => 'Use JSON if you plan to import the data into Invoice Ninja.<br/>The file includes clients, products, invoices, quotes and payments.',
    'selfhost_export_help' => '<br/>We recommend using mysqldump to create a full backup.',
    'JSON_file' => 'Fajlli JSON',

    'view_dashboard' => 'Shiko Panelin',
    'client_session_expired' => 'Seanca ka skaduar.',
    'client_session_expired_message' => 'Seanca ka skaduar. Ju lutem klikoni linkun në emailin tuaj përsëri.',

    'auto_bill_notification' => 'Kjo faturë do të dërgohet për pagesë automatikisht tek  :payment_method në :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'llogaria bankare',
    'auto_bill_payment_method_credit_card' => 'kredit kartë',
    'auto_bill_payment_method_paypal' => 'Llogaria PayPal',
    'auto_bill_notification_placeholder' => 'Kjo faturë do të dërgohet për pagesë automatikisht nga kredit karta juaj në afatin e pagesës.',
    'payment_settings' => 'Rregullimi i pagesës',

    'on_send_date' => 'Në datën e dërgimit',
    'on_due_date' => 'Në datën e pagesës',
    'auto_bill_ach_date_help' => 'ACH will always auto bill on the due date.',
    'warn_change_auto_bill' => 'Për shkak të rregullave të NACHA, ndryshimet në këtë faturë mund të parandalojnë autopagesën përmes ACH.',

    'bank_account' => 'Llogaria Bankare',
    'payment_processed_through_wepay' => 'Pagesat ACH do të procesohen përmes WePay.',
    'wepay_payment_tos_agree' => 'Pajtohem me WePay :terms dhe:privacy_policy.',
    'privacy_policy' => 'Politika e Privatësisë',
    'wepay_payment_tos_agree_required' => 'Ju duhet të pajtoheni me WePay Kushtet e Shërbimit dhe Politikat e Privatësisë.',
    'ach_email_prompt' => 'Ju lutem vendosni email adresën tuaj:',
    'verification_pending' => 'Verifikimi në pritje',

    'update_font_cache' => 'Ju lutem freskojeni faqen për të parë fontin.',
    'more_options' => 'Më shumë opsione',
    'credit_card' => 'Kredit kartë',
    'bank_transfer' => 'Transfer bankar',
    'no_transaction_reference' => 'Nuk kemi pranuar referencën e transaksionit të pagesës nga kanali i pagesës.',
    'use_bank_on_file' => 'Përdorni bankën e regjistruar',
    'auto_bill_email_message' => 'Kjo faturë do të dërgohet për pagesë automatikisht tek opsioni i pagesës në afatin e pagesës.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Shtuar :date',
    'failed_remove_payment_method' => 'Ka dështuar largimi i metodës së pagesës',
    'gateway_exists' => 'Ky kanal pagese tashmë ekziston',
    'manual_entry' => 'Vendos manualisht',
    'start_of_week' => 'First Day of the Week',

    // Frequencies
    'freq_inactive' => 'Inactive',
    'freq_daily' => 'Daily',
    'freq_weekly' => 'Javore',
    'freq_biweekly' => 'Biweekly',
    'freq_two_weeks' => 'Dy javore',
    'freq_four_weeks' => 'Katër javore',
    'freq_monthly' => 'Mujore',
    'freq_three_months' => 'Tre mujore',
    'freq_four_months' => 'Four months',
    'freq_six_months' => 'Gjashtë mujore',
    'freq_annually' => 'Vjetore',
    'freq_two_years' => 'Two years',

    // Payment types
    'payment_type_Apply Credit' => 'Apliko kreditin',
    'payment_type_Bank Transfer' => 'Transfer bankar',
    'payment_type_Cash' => 'Kesh',
    'payment_type_Debit' => 'Debit',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa Card',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Tjetër Credit Card',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Qeqe',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Kalo',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Kontabilitet & Ligjore',
    'industry_Advertising' => 'Reklamimi',
    'industry_Aerospace' => 'Aerospace',
    'industry_Agriculture' => 'Agrikultura',
    'industry_Automotive' => 'Automobilizëm',
    'industry_Banking & Finance' => 'Banka dhe Financa',
    'industry_Biotechnology' => 'Bioteknologji',
    'industry_Broadcasting' => 'Transmetim',
    'industry_Business Services' => 'Shërbime biznesi',
    'industry_Commodities & Chemicals' => 'Kemikale',
    'industry_Communications' => 'Komunikimi',
    'industry_Computers & Hightech' => 'Kompjuter & Tekonologji',
    'industry_Defense' => 'Mbrojtje',
    'industry_Energy' => 'Energji',
    'industry_Entertainment' => 'Zbavitje',
    'industry_Government' => 'Qeveri',
    'industry_Healthcare & Life Sciences' => 'Shëndetësi & Shkencë',
    'industry_Insurance' => 'Sigurime',
    'industry_Manufacturing' => 'Prodhi',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'OJQ',
    'industry_Pharmaceuticals' => 'Farmaceutike',
    'industry_Professional Services & Consulting' => 'Shërbime profesionale & konsultim',
    'industry_Real Estate' => 'Patundshmëri',
    'industry_Restaurant & Catering' => 'Restaurant & Catering',
    'industry_Retail & Wholesale' => 'Shitje',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Udhëtime & Luks',
    'industry_Other' => 'Të tjera',
    'industry_Photography' => 'Fotografi',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarctica',
    'country_Algeria' => 'Algeria',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua and Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australia',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgium',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosnia and Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brazil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgaria',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Belarus',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Cameroon',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cape Verde',
    'country_Cayman Islands' => 'Cayman Islands',
    'country_Central African Republic' => 'Central African Republic',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Chile',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan, Province of China',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'Congo, the Democratic Republic of the',
    'country_Cook Islands' => 'Cook Islands',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croatia',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cyprus',
    'country_Czech Republic' => 'Czech Republic',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Denmark',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominican Republic',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Ethiopia',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estonia',
    'country_Faroe Islands' => 'Faroe Islands',
    'country_Falkland Islands (Malvinas)' => 'Falkland Islands (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia and the South Sandwich Islands',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'France',
    'country_French Guiana' => 'French Guiana',
    'country_French Polynesia' => 'French Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Germany',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Greece',
    'country_Greenland' => 'Greenland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Holy See (Vatican City State)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Hungary',
    'country_Iceland' => 'Iceland',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesia',
    'country_Iran, Islamic Republic of' => 'Iran, Islamic Republic of',
    'country_Iraq' => 'Iraq',
    'country_Ireland' => 'Ireland',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italy',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Lebanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Latvia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libya',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lithuania',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexico',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Netherlands',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'New Zealand',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norway',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua New Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Poland',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Romania',
    'country_Russian Federation' => 'Russian Federation',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Saudi Arabia',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakia',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Slovenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'South Africa',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spain',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sweden',
    'country_Switzerland' => 'Switzerland',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad and Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunisia',
    'country_Turkey' => 'Turkey',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia, the former Yugoslav Republic of',
    'country_Egypt' => 'Egypt',
    'country_United Kingdom' => 'United Kingdom',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'United States',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarian Republic of',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brazilian Portuguese',
    'lang_Croatian' => 'Croatian',
    'lang_Czech' => 'Czech',
    'lang_Danish' => 'Danish',
    'lang_Dutch' => 'Dutch',
    'lang_English' => 'English',
    'lang_French' => 'French',
    'lang_French - Canada' => 'French - Canada',
    'lang_German' => 'German',
    'lang_Italian' => 'Italian',
    'lang_Japanese' => 'Japanese',
    'lang_Lithuanian' => 'Lithuanian',
    'lang_Norwegian' => 'Norwegian',
    'lang_Polish' => 'Polish',
    'lang_Spanish' => 'Spanish',
    'lang_Spanish - Spain' => 'Spanish - Spain',
    'lang_Swedish' => 'Swedish',
    'lang_Albanian' => 'Shqip',
    'lang_Greek' => 'Greek',
    'lang_English - United Kingdom' => 'English - United Kingdom',
    'lang_English - Australia' => 'English - Australia',
    'lang_Slovenian' => 'Slovenian',
    'lang_Finnish' => 'Finnish',
    'lang_Romanian' => 'Romanian',
    'lang_Turkish - Turkey' => 'Turkish - Turkey',
    'lang_Portuguese - Brazilian' => 'Portuguese - Brazilian',
    'lang_Portuguese - Portugal' => 'Portuguese - Portugal',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Macedonian',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Serbian',
    'lang_Bulgarian' => 'Bulgarian',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Kontabilitet & Ligjore',
    'industry_Advertising' => 'Reklamimi',
    'industry_Aerospace' => 'Aerospace',
    'industry_Agriculture' => 'Agrikultura',
    'industry_Automotive' => 'Automobilizëm',
    'industry_Banking & Finance' => 'Banka dhe Financa',
    'industry_Biotechnology' => 'Bioteknologji',
    'industry_Broadcasting' => 'Transmetim',
    'industry_Business Services' => 'Shërbime biznesi',
    'industry_Commodities & Chemicals' => 'Kemikale',
    'industry_Communications' => 'Komunikimi',
    'industry_Computers & Hightech' => 'Kompjuter & Tekonologji',
    'industry_Defense' => 'Mbrojtje',
    'industry_Energy' => 'Energji',
    'industry_Entertainment' => 'Zbavitje',
    'industry_Government' => 'Qeveri',
    'industry_Healthcare & Life Sciences' => 'Shëndetësi & Shkencë',
    'industry_Insurance' => 'Sigurime',
    'industry_Manufacturing' => 'Prodhi',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'OJQ',
    'industry_Pharmaceuticals' => 'Farmaceutike',
    'industry_Professional Services & Consulting' => 'Shërbime profesionale & konsultim',
    'industry_Real Estate' => 'Patundshmëri',
    'industry_Retail & Wholesale' => 'Shitje',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Udhëtime & Luks',
    'industry_Other' => 'Të tjera',
    'industry_Photography' => 'Fotografi',

    'view_client_portal' => 'Shiko portalin e klienti',
    'view_portal' => 'Shiko portalin',
    'vendor_contacts' => 'Kontakte te kompanive',
    'all' => 'Të gjitha',
    'selected' => 'Të selektuara',
    'category' => 'Kategoria',
    'categories' => 'Kategoritë',
    'new_expense_category' => 'Kategori e re e shpenzimeve',
    'edit_category' => 'Edito kategorinë',
    'archive_expense_category' => 'Arkivo kategorinë',
    'expense_categories' => 'Kategoritë e shpenzimeve',
    'list_expense_categories' => 'Listo kategoritë e shpenzimeve',
    'updated_expense_category' => 'Është perditesuar me sukses kategoria e shpenzimeve',
    'created_expense_category' => 'Kategoria e shpenzimeve është krijuar me sukses',
    'archived_expense_category' => 'Kategoria e shpenzimeve është arkivuar me sukses',
    'archived_expense_categories' => ':count kategori të shpenzimeve janë arkivuar me sukses',
    'restore_expense_category' => 'Rikthe kategorinë e shpenzimeve',
    'restored_expense_category' => 'Kategoria e shpenzimeve është rikthyer me sukses',
    'apply_taxes' => 'Apliko taksat',
    'min_to_max_users' => ':min deri :max përdorues',
    'max_users_reached' => 'Numri maksimal i përdoruesve është arritur',
    'buy_now_buttons' => 'Butonat Blej Tash',
    'landing_page' => 'Faqja hyrëse',
    'payment_type' => 'Lloji i pagesës',
    'form' => 'Forma',
    'link' => 'Link',
    'fields' => 'Fushat',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Note: the client and invoice are created even if the transaction isn\'t completed.',
    'buy_now_buttons_disabled' => 'Ky opsion kërkon që produkti të jetë i krijuar dhe të konfigurohet kanali i pagesës.',
    'enable_buy_now_buttons_help' => 'Aktivizo përkrahjen për butonat Blej Tash',
    'changes_take_effect_immediately' => 'Shënim: ndryshimet kanë efekt të menjëhershëm',
    'wepay_account_description' => 'Kanalet e pagesës për Invoice Ninja',
    'payment_error_code' => 'Ka ndodhur një gabim gjatë procesimit të pagesës tuaj [:code]. Ju lutem provoni më vonë përsëri.',
    'standard_fees_apply' => 'Fee: 2.9%/1.2% [Credit Card/Bank Transfer] + $0.30 per successful charge.',
    'limit_import_rows' => 'Të dhënat duhet të të importohen për :count rreshta ose më pak',
    'error_title' => 'Diçka ka shkuar gabim',
    'error_contact_text' => 'Nëse dëshironi të ndihmoni ju lutem na shkruani email në :mailaddress',
    'no_undo' => 'Vërejtje: kjo nuk mund të kthehet prapa.',
    'no_contact_selected' => 'Ju lutem zgjedhni një kontakt',
    'no_client_selected' => 'Ju lutem zgjedhni një klient',

    'gateway_config_error' => 'Mund t\'ju duhet ndihmë për të vendosur fjalëkalim të ri ose për të gjeneruar çelës të ri API .',
    'payment_type_on_file' => ':type ne skedar',
    'invoice_for_client' => 'Fatura :invoice per :client',
    'intent_not_found' => 'Me falni, nuk jam i sigurt cfare kerkoni. ',
    'intent_not_supported' => 'Me falni, nuk jam ne gjendje te bej kete gje. ',
    'client_not_found' => 'Nuk ishte e mundur te gjeja klientin',
    'not_allowed' => 'Me falni, ju nuk keni autorizimin perkates',
    'bot_emailed_invoice' => 'Fatura juaj u dergua. ',
    'bot_emailed_notify_viewed' => 'Do te te dergoj email kur te shikohet. ',
    'bot_emailed_notify_paid' => 'Do te te dergoj email kur te paguhet. ',
    'add_product_to_invoice' => 'Shto 1 :product',
    'not_authorized' => 'Nuk jeni i autorizuar. ',
    'bot_get_email' => 'Hi! (wave)<br/>Thanks for trying the Invoice Ninja Bot.<br/>You need to create a free account to use this bot.<br/>Send me your account email address to get started.',
    'bot_get_code' => 'Faleminderit. Ju kam dergar nje email qe permban kodin tuaj te sigurise. ',
    'bot_welcome' => 'Llogaria juaj eshte verifikuar.<br/>',
    'email_not_found' => 'Nuk munda te gjej nje llogari te disponueshme per :email',
    'invalid_code' => 'Kodi eshte jo korrekt',
    'security_code_email_subject' => 'Kodi i sigurise per Invoice Ninja Bot',
    'security_code_email_line1' => 'Ky eshte kodi juaj i sigurise per Invoice Ninja Bot. ',
    'security_code_email_line2' => 'Shenim: skadon per 10 minuta.',
    'bot_help_message' => 'Momentalisht mund te bej:<br/>• Krijo/perditeso/dergo nje fature<br/>• Listo produktet<br/>Per shembull:<br/><i>Dergo fature Bobit per 2 bileta me date te fundit per te enjten tjeter dhe ul cmimin me 10 perqind<i>',
    'list_products' => 'Listo Produktet',

    'include_item_taxes_inline' => 'Perfshi <b>line item taxes in line total</b>',
    'created_quotes' => 'Jane krijuar me sukses :count oferta',
    'limited_gateways' => 'Shenim: ne ofrojme nje kanal pagese me karte krediti per kompani.',

    'warning' => 'Paralajmerim',
    'self-update' => 'Perditeso',
    'update_invoiceninja_title' => 'Perditeso Invoice Ninja',
    'update_invoiceninja_warning' => 'Perpara se te perditesoni Invoice Ninja, ruani nje rezerve te skedareve dhe databazes!',
    'update_invoiceninja_available' => 'Nje version i ri i Invoice Ninja eshte i disponueshem. ',
    'update_invoiceninja_unavailable' => 'Nuk ka version te ri te disponueshem per Invoice Ninja. ',
    'update_invoiceninja_instructions' => 'Ju lutem instaloni versionin e ri <strong>:version</strong> duke klikuar butonin <em>Perditeso Tani</em> me poshte. Pasi te mbaroje, do te dergoheni ne faqen kryesore.',
    'update_invoiceninja_update_start' => 'Perditeso tani',
    'update_invoiceninja_download_start' => 'Shkarko :version',
    'create_new' => 'Krijo',

    'toggle_navigation' => 'Ndrysho Navigimin',
    'toggle_history' => 'Ndrysho Historine',
    'unassigned' => 'E pacaktuar',
    'task' => 'Detyre',
    'contact_name' => 'Emri i Kontaktit',
    'city_state_postal' => 'Qytet/Shtet/Poste',
    'custom_field' => 'Fushe e Ndryshueshme',
    'account_fields' => 'Fushat e kompanise',
    'facebook_and_twitter' => 'Facebook dhe Twitter',
    'facebook_and_twitter_help' => 'Ndiqni te rejat tona per te na perkrahur',
    'reseller_text' => 'Note: the white-label license is intended for personal use, please email us at :email if you\'d like to resell the app.',
    'unnamed_client' => 'Klient pa Emer',

    'day' => 'Dite',
    'week' => 'Jave',
    'month' => 'Muaj',
    'inactive_logout' => 'Ju jeni c\'rregjistruar sepse nuk ishit aktiv',
    'reports' => 'Raporte',
    'total_profit' => 'Fitimi Total',
    'total_expenses' => 'Shpenzimet Totale',
    'quote_to' => 'Oferte per',

    // Limits
    'limit' => 'Limit',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'Pa Limit',
    'set_limits' => 'Vendos Limitet per :gateway_type',
    'enable_min' => 'Aktivizo min',
    'enable_max' => 'Aktivizo max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'Kjo fature nuk respekton limitet per kete kanal pagese.',

    'date_range' => 'Shtrirja e Dates',
    'raw' => 'Raw',
    'raw_html' => 'Raw HTML',
    'update' => 'Perditeso',
    'invoice_fields_help' => 'Leviz fushat me "drag and drop" per te ndryshuar rregullin dhe vendndodhjen',
    'new_category' => 'Kategori e Re',
    'restore_product' => 'Rikthe Produktin',
    'blank' => 'Bosh',
    'invoice_save_error' => 'There was an error saving your invoice',
    'enable_recurring' => 'Aktivizo Perseritjen',
    'disable_recurring' => 'Caktivizo Perseritjen',
    'text' => 'Tekst',
    'expense_will_create' => 'expense will be created',
    'expenses_will_create' => 'expenses will be created',
    'created_expenses' => 'Successfully created :count expense(s)',

    'translate_app' => 'Help improve our translations with :link',
    'expense_category' => 'Expense Category',

    'go_ninja_pro' => 'Go Ninja Pro!',
    'go_enterprise' => 'Go Enterprise!',
    'upgrade_for_features' => 'Upgrade For More Features',
    'pay_annually_discount' => 'Pay annually for 10 months + 2 free!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'YourBrand.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Customize every aspect of your invoice!',
    'enterprise_upgrade_feature1' => 'Set permissions for multiple-users',
    'enterprise_upgrade_feature2' => 'Attach 3rd party files to invoices & expenses',
    'much_more' => 'Much More!',
    'all_pro_fetaures' => 'Plus all pro features!',

    'currency_symbol' => 'Symbol',
    'currency_code' => 'Code',

    'buy_license' => 'Buy License',
    'apply_license' => 'Apply License',
    'submit' => 'Submit',
    'white_label_license_key' => 'License Key',
    'invalid_white_label_license' => 'The white label license is not valid',
    'created_by' => 'Created by :name',
    'modules' => 'Modules',
    'financial_year_start' => 'First Month of the Year',
    'authentication' => 'Authentication',
    'checkbox' => 'Checkbox',
    'invoice_signature' => 'Signature',
    'show_accept_invoice_terms' => 'Invoice Terms Checkbox',
    'show_accept_invoice_terms_help' => 'Require client to confirm that they accept the invoice terms.',
    'show_accept_quote_terms' => 'Quote Terms Checkbox',
    'show_accept_quote_terms_help' => 'Require client to confirm that they accept the quote terms.',
    'require_invoice_signature' => 'Invoice Signature',
    'require_invoice_signature_help' => 'Require client to provide their signature.',
    'require_quote_signature' => 'Quote Signature',
    'require_quote_signature_help' => 'Require client to provide their signature.',
    'i_agree' => 'I Agree To The Terms',
    'sign_here' => 'Please sign here:',
    'authorization' => 'Authorization',
    'signed' => 'Signed',

    // BlueVine
    'bluevine_promo' => 'Get flexible business lines of credit and invoice factoring using BlueVine.',
    'bluevine_modal_label' => 'Sign up with BlueVine',
    'bluevine_modal_text' => '<h3>Fast funding for your business. No paperwork.</h3>
<ul><li>Flexible business lines of credit and invoice factoring.</li></ul>',
    'bluevine_create_account' => 'Create an account',
    'quote_types' => 'Get a quote for',
    'invoice_factoring' => 'Invoice factoring',
    'line_of_credit' => 'Line of credit',
    'fico_score' => 'Your FICO score',
    'business_inception' => 'Business Inception Date',
    'average_bank_balance' => 'Average bank account balance',
    'annual_revenue' => 'Annual revenue',
    'desired_credit_limit_factoring' => 'Desired invoice factoring limit',
    'desired_credit_limit_loc' => 'Desired line of credit limit',
    'desired_credit_limit' => 'Desired credit limit',
    'bluevine_credit_line_type_required' => 'You must choose at least one',
    'bluevine_field_required' => 'This field is required',
    'bluevine_unexpected_error' => 'An unexpected error occurred.',
    'bluevine_no_conditional_offer' => 'More information is required before getting a quote. Click continue below.',
    'bluevine_invoice_factoring' => 'Invoice Factoring',
    'bluevine_conditional_offer' => 'Conditional Offer',
    'bluevine_credit_line_amount' => 'Credit Line',
    'bluevine_advance_rate' => 'Advance Rate',
    'bluevine_weekly_discount_rate' => 'Weekly Discount Rate',
    'bluevine_minimum_fee_rate' => 'Minimum Fee',
    'bluevine_line_of_credit' => 'Line of Credit',
    'bluevine_interest_rate' => 'Interest Rate',
    'bluevine_weekly_draw_rate' => 'Weekly Draw Rate',
    'bluevine_continue' => 'Continue to BlueVine',
    'bluevine_completed' => 'BlueVine signup completed',

    'vendor_name' => 'Vendor',
    'entity_state' => 'State',
    'client_created_at' => 'Date Created',
    'postmark_error' => 'There was a problem sending the email through Postmark: :link',
    'project' => 'Project',
    'projects' => 'Projects',
    'new_project' => 'New Project',
    'edit_project' => 'Edit Project',
    'archive_project' => 'Archive Project',
    'list_projects' => 'List Projects',
    'updated_project' => 'Successfully updated project',
    'created_project' => 'Successfully created project',
    'archived_project' => 'Successfully archived project',
    'archived_projects' => 'Successfully archived :count projects',
    'restore_project' => 'Restore Project',
    'restored_project' => 'Successfully restored project',
    'delete_project' => 'Delete Project',
    'deleted_project' => 'Successfully deleted project',
    'deleted_projects' => 'Successfully deleted :count projects',
    'delete_expense_category' => 'Delete category',
    'deleted_expense_category' => 'Successfully deleted category',
    'delete_product' => 'Delete Product',
    'deleted_product' => 'Successfully deleted product',
    'deleted_products' => 'Successfully deleted :count products',
    'restored_product' => 'Successfully restored product',
    'update_credit' => 'Update Credit',
    'updated_credit' => 'Successfully updated credit',
    'edit_credit' => 'Edit Credit',
    'realtime_preview' => 'Realtime Preview',
    'realtime_preview_help' => 'Realtime refresh PDF preview on the invoice page when editing invoice.<br/>Disable this to improve performance when editing invoices.',
    'live_preview_help' => 'Display a live PDF preview on the invoice page.',
    'force_pdfjs_help' => 'Replace the built-in PDF viewer in :chrome_link and :firefox_link.<br/>Enable this if your browser is automatically downloading the PDF.',
    'force_pdfjs' => 'Prevent Download',
    'redirect_url' => 'Redirect URL',
    'redirect_url_help' => 'Optionally specify a URL to redirect to after a payment is entered.',
    'save_draft' => 'Save Draft',
    'refunded_credit_payment' => 'Refunded credit payment',
    'keyboard_shortcuts' => 'Keyboard Shortcuts',
    'toggle_menu' => 'Toggle Menu',
    'new_...' => 'New ...',
    'list_...' => 'List ...',
    'created_at' => 'Date Created',
    'contact_us' => 'Contact Us',
    'user_guide' => 'User Guide',
    'promo_message' => 'Upgrade before :expires and get :amount OFF your first year of our Pro or Enterprise packages.',
    'discount_message' => ':amount off expires :expires',
    'mark_paid' => 'Mark Paid',
    'marked_sent_invoice' => 'Successfully marked invoice sent',
    'marked_sent_invoices' => 'Successfully marked invoices sent',
    'invoice_name' => 'Invoice',
    'product_will_create' => 'product will be created',
    'contact_us_response' => 'Thank you for your message! We\'ll try to respond as soon as possible.',
    'last_7_days' => 'Last 7 Days',
    'last_30_days' => 'Last 30 Days',
    'this_month' => 'This Month',
    'last_month' => 'Last Month',
    'current_quarter' => 'Current Quarter',
    'last_quarter' => 'Last Quarter',
    'last_year' => 'Last Year',
    'custom_range' => 'Custom Range',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Require',
    'license_expiring' => 'Note: Your license will expire in :count days, :link to renew it.',
    'security_confirmation' => 'Your email address has been confirmed.',
    'white_label_expired' => 'Your white label license has expired, please consider renewing it to help support our project.',
    'renew_license' => 'Renew License',
    'iphone_app_message' => 'Consider downloading our :link',
    'iphone_app' => 'iPhone app',
    'android_app' => 'Android app',
    'logged_in' => 'Logged In',
    'switch_to_primary' => 'Switch to your primary company (:name) to manage your plan.',
    'inclusive' => 'Inclusive',
    'exclusive' => 'Exclusive',
    'postal_city_state' => 'Postal/City/State',
    'phantomjs_help' => 'In certain cases the app uses :link_phantom to generate the PDF, install :link_docs to generate it locally.',
    'phantomjs_local' => 'Using local PhantomJS',
    'client_number' => 'Client Number',
    'client_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the client number.',
    'next_client_number' => 'The next client number is :number.',
    'generated_numbers' => 'Generated Numbers',
    'notes_reminder1' => 'First Reminder',
    'notes_reminder2' => 'Second Reminder',
    'notes_reminder3' => 'Third Reminder',
    'notes_reminder4' => 'Reminder',
    'bcc_email' => 'BCC Email',
    'tax_quote' => 'Tax Quote',
    'tax_invoice' => 'Tax Invoice',
    'emailed_invoices' => 'Successfully emailed invoices',
    'emailed_quotes' => 'Successfully emailed quotes',
    'website_url' => 'Website URL',
    'domain' => 'Domain',
    'domain_help' => 'Used in the client portal and when sending emails.',
    'domain_help_website' => 'Used when sending emails.',
    'import_invoices' => 'Import Invoices',
    'new_report' => 'New Report',
    'edit_report' => 'Edit Report',
    'columns' => 'Columns',
    'filters' => 'Filters',
    'sort_by' => 'Sort By',
    'draft' => 'Draft',
    'unpaid' => 'Unpaid',
    'aging' => 'Aging',
    'age' => 'Age',
    'days' => 'Days',
    'age_group_0' => '0 - 30 Days',
    'age_group_30' => '30 - 60 Days',
    'age_group_60' => '60 - 90 Days',
    'age_group_90' => '90 - 120 Days',
    'age_group_120' => '120+ Days',
    'invoice_details' => 'Invoice Details',
    'qty' => 'Quantity',
    'profit_and_loss' => 'Profit and Loss',
    'revenue' => 'Revenue',
    'profit' => 'Profit',
    'group_when_sorted' => 'Group Sort',
    'group_dates_by' => 'Group Dates By',
    'year' => 'Year',
    'view_statement' => 'View Statement',
    'statement' => 'Statement',
    'statement_date' => 'Statement Date',
    'mark_active' => 'Mark Active',
    'send_automatically' => 'Send Automatically',
    'initial_email' => 'Initial Email',
    'invoice_not_emailed' => 'This invoice hasn\'t been emailed.',
    'quote_not_emailed' => 'This quote hasn\'t been emailed.',
    'sent_by' => 'Sent by :user',
    'recipients' => 'Recipients',
    'save_as_default' => 'Save as default',
    'start_of_week_help' => 'Used by <b>date</b> selectors',
    'financial_year_start_help' => 'Used by <b>date range</b> selectors',
    'reports_help' => 'Shift + Click to sort by multiple columns, Ctrl + Click to clear the grouping.',
    'this_year' => 'This Year',

    // Updated login screen
    'ninja_tagline' => 'Create. Send. Get Paid.',
    'login_or_existing' => 'Or login with a connected account.',
    'sign_up_now' => 'Sign Up Now',
    'not_a_member_yet' => 'Not a member yet?',
    'login_create_an_account' => 'Create an Account!',

    // New Client Portal styling
    'invoice_from' => 'Invoices From:',
    'email_alias_message' => 'We require each company to have a unique email address.<br/>Consider using an alias. ie, email+label@example.com',
    'full_name' => 'Full Name',
    'month_year' => 'MONTH/YEAR',
    'valid_thru' => 'Valid\nthru',

    'product_fields' => 'Product Fields',
    'custom_product_fields_help' => 'Add a field when creating a product or invoice and display the label and value on the PDF.',
    'freq_two_months' => 'Two months',
    'freq_yearly' => 'Annually',
    'profile' => 'Profile',
    'payment_type_help' => 'Sets the default <b>manual payment type</b>.',
    'industry_Construction' => 'Construction',
    'your_statement' => 'Your Statement',
    'statement_issued_to' => 'Statement issued to',
    'statement_to' => 'Statement to',
    'customize_options' => 'Customize options',
    'created_payment_term' => 'Successfully created payment term',
    'updated_payment_term' => 'Successfully updated payment term',
    'archived_payment_term' => 'Successfully archived payment term',
    'resend_invite' => 'Resend Invitation',
    'credit_created_by' => 'Credit created by payment :transaction_reference',
    'created_payment_and_credit' => 'Successfully created payment and credit',
    'created_payment_and_credit_emailed_client' => 'Successfully created payment and credit, and emailed client',
    'create_project' => 'Create project',
    'create_vendor' => 'Create vendor',
    'create_expense_category' => 'Create category',
    'pro_plan_reports' => ':link to enable reports by joining the Pro Plan',
    'mark_ready' => 'Mark Ready',

    'limits' => 'Limits',
    'fees' => 'Fees',
    'fee' => 'Fee',
    'set_limits_fees' => 'Set :gateway_type Limits/Fees',
    'fees_tax_help' => 'Enable line item taxes to set the fee tax rates.',
    'fees_sample' => 'The fee for a :amount invoice would be :total.',
    'discount_sample' => 'The discount for a :amount invoice would be :total.',
    'no_fees' => 'No Fees',
    'gateway_fees_disclaimer' => 'Warning: not all states/payment gateways allow adding fees, please review local laws/terms of service.',
    'percent' => 'Percent',
    'location' => 'Location',
    'line_item' => 'Line Item',
    'surcharge' => 'Surcharge',
    'location_first_surcharge' => 'Enabled - First surcharge',
    'location_second_surcharge' => 'Enabled - Second surcharge',
    'location_line_item' => 'Enabled - Line item',
    'online_payment_surcharge' => 'Online Payment Surcharge',
    'gateway_fees' => 'Gateway Fees',
    'fees_disabled' => 'Fees are disabled',
    'gateway_fees_help' => 'Automatically add an online payment surcharge/discount.',
    'gateway' => 'Gateway',
    'gateway_fee_change_warning' => 'If there are unpaid invoices with fees they need to be updated manually.',
    'fees_surcharge_help' => 'Customize surcharge :link.',
    'label_and_taxes' => 'label and taxes',
    'billable' => 'Billable',
    'logo_warning_too_large' => 'The image file is too large.',
    'logo_warning_fileinfo' => 'Warning: To support gifs the fileinfo PHP extension needs to be enabled.',
    'logo_warning_invalid' => 'There was a problem reading the image file, please try a different format.',

    'error_refresh_page' => 'An error occurred, please refresh the page and try again.',
    'data' => 'Data',
    'imported_settings' => 'Successfully imported settings',
    'reset_counter' => 'Reset Counter',
    'next_reset' => 'Next Reset',
    'reset_counter_help' => 'Automatically reset the invoice and quote counters.',
    'auto_bill_failed' => 'Auto-billing for invoice :invoice_number failed',
    'online_payment_discount' => 'Online Payment Discount',
    'created_new_company' => 'Successfully created new company',
    'fees_disabled_for_gateway' => 'Fees are disabled for this gateway.',
    'logout_and_delete' => 'Log Out/Delete Account',
    'tax_rate_type_help' => 'Inclusive tax rates adjust the line item cost when selected.<br/>Only exclusive tax rates can be used as a default.',
    'invoice_footer_help' => 'Use $pageNumber and $pageCount to display the page information.',
    'credit_note' => 'Credit Note',
    'credit_issued_to' => 'Credit issued to',
    'credit_to' => 'Credit to',
    'your_credit' => 'Your Credit',
    'credit_number' => 'Credit Number',
    'create_credit_note' => 'Create Credit Note',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Error: The gateways table has incorrect ids.',
    'purge_data' => 'Purge Data',
    'delete_data' => 'Delete Data',
    'purge_data_help' => 'Permanently delete all data but keep the account and settings.',
    'cancel_account_help' => 'Permanently delete the account along with all data and setting.',
    'purge_successful' => 'Successfully purged company data',
    'forbidden' => 'Forbidden',
    'purge_data_message' => 'Warning: This will permanently erase your data, there is no undo.',
    'contact_phone' => 'Contact Phone',
    'contact_email' => 'Contact Email',
    'reply_to_email' => 'Reply-To Email',
    'reply_to_email_help' => 'Specify the reply-to address for client emails.',
    'bcc_email_help' => 'Privately include this address with client emails.',
    'import_complete' => 'Your import has successfully completed.',
    'confirm_account_to_import' => 'Please confirm your account to import data.',
    'import_started' => 'Your import has started, we\'ll send you an email once it completes.',
    'listening' => 'Listening...',
    'microphone_help' => 'Say "new invoice for [client]" or "show me [client]\'s archived payments"',
    'voice_commands' => 'Voice Commands',
    'sample_commands' => 'Sample commands',
    'voice_commands_feedback' => 'We\'re actively working to improve this feature, if there\'s a command you\'d like us to support please email us at :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Money Order',
    'archived_products' => 'Successfully archived :count products',
    'recommend_on' => 'We recommend <b>enabling</b> this setting.',
    'recommend_off' => 'We recommend <b>disabling</b> this setting.',
    'notes_auto_billed' => 'Auto-billed',
    'surcharge_label' => 'Surcharge Label',
    'contact_fields' => 'Contact Fields',
    'custom_contact_fields_help' => 'Add a field when creating a contact and optionally display the label and value on the PDF.',
    'datatable_info' => 'Showing :start to :end of :total entries',
    'credit_total' => 'Credit Total',
    'mark_billable' => 'Mark billable',
    'billed' => 'Billed',
    'company_variables' => 'Company Variables',
    'client_variables' => 'Client Variables',
    'invoice_variables' => 'Invoice Variables',
    'navigation_variables' => 'Navigation Variables',
    'custom_variables' => 'Custom Variables',
    'invalid_file' => 'Invalid file type',
    'add_documents_to_invoice' => 'Add documents to invoice',
    'mark_expense_paid' => 'Mark paid',
    'white_label_license_error' => 'Failed to validate the license, check storage/logs/laravel-error.log for more details.',
    'plan_price' => 'Plan Price',
    'wrong_confirmation' => 'Incorrect confirmation code',
    'oauth_taken' => 'The account is already registered',
    'emailed_payment' => 'Successfully emailed payment',
    'email_payment' => 'Email Payment',
    'invoiceplane_import' => 'Use :link to migrate your data from InvoicePlane.',
    'duplicate_expense_warning' => 'Warning: This :link may be a duplicate',
    'expense_link' => 'expense',
    'resume_task' => 'Resume Task',
    'resumed_task' => 'Successfully resumed task',
    'quote_design' => 'Quote Design',
    'default_design' => 'Standard Design',
    'custom_design1' => 'Custom Design 1',
    'custom_design2' => 'Custom Design 2',
    'custom_design3' => 'Custom Design 3',
    'empty' => 'Empty',
    'load_design' => 'Load Design',
    'accepted_card_logos' => 'Accepted Card Logos',
    'phantomjs_local_and_cloud' => 'Using local PhantomJS, falling back to phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Track payments using :link',
    'start_date_required' => 'The start date is required',
    'application_settings' => 'Application Settings',
    'database_connection' => 'Database Connection',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'Database',
    'test_connection' => 'Test connection',
    'from_name' => 'From Name',
    'from_address' => 'From Address',
    'port' => 'Port',
    'encryption' => 'Encryption',
    'mailgun_domain' => 'Mailgun Domain',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'Send test email',
    'select_label' => 'Select Label',
    'label' => 'Label',
    'service' => 'Service',
    'update_payment_details' => 'Update payment details',
    'updated_payment_details' => 'Successfully updated payment details',
    'update_credit_card' => 'Update Credit Card',
    'recurring_expenses' => 'Recurring Expenses',
    'recurring_expense' => 'Recurring Expense',
    'new_recurring_expense' => 'New Recurring Expense',
    'edit_recurring_expense' => 'Edit Recurring Expense',
    'archive_recurring_expense' => 'Archive Recurring Expense',
    'list_recurring_expense' => 'List Recurring Expenses',
    'updated_recurring_expense' => 'Successfully updated recurring expense',
    'created_recurring_expense' => 'Successfully created recurring expense',
    'archived_recurring_expense' => 'Successfully archived recurring expense',
    'restore_recurring_expense' => 'Restore Recurring Expense',
    'restored_recurring_expense' => 'Successfully restored recurring expense',
    'delete_recurring_expense' => 'Delete Recurring Expense',
    'deleted_recurring_expense' => 'Successfully deleted project',
    'view_recurring_expense' => 'View Recurring Expense',
    'taxes_and_fees' => 'Taxes and fees',
    'import_failed' => 'Import Failed',
    'recurring_prefix' => 'Recurring Prefix',
    'options' => 'Options',
    'credit_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the credit number for negative invoices.',
    'next_credit_number' => 'The next credit number is :number.',
    'padding_help' => 'The number of zero\'s to pad the number.',
    'import_warning_invalid_date' => 'Warning: The date format appears to be invalid.',
    'product_notes' => 'Product Notes',
    'app_version' => 'App Version',
    'ofx_version' => 'OFX Version',
    'gateway_help_23' => ':link to get your Stripe API keys.',
    'error_app_key_set_to_default' => 'Error: APP_KEY is set to a default value, to update it backup your database and then run <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Charge Late Fee',
    'late_fee_amount' => 'Late Fee Amount',
    'late_fee_percent' => 'Late Fee Percent',
    'late_fee_added' => 'Late fee added on :date',
    'download_invoice' => 'Download Invoice',
    'download_quote' => 'Download Quote',
    'invoices_are_attached' => 'Your invoice PDFs are attached.',
    'downloaded_invoice' => 'An email will be sent with the invoice PDF',
    'downloaded_quote' => 'An email will be sent with the quote PDF',
    'downloaded_invoices' => 'An email will be sent with the invoice PDFs',
    'downloaded_quotes' => 'An email will be sent with the quote PDFs',
    'clone_expense' => 'Clone Expense',
    'default_documents' => 'Default Documents',
    'send_email_to_client' => 'Send email to the client',
    'refund_subject' => 'Refund Processed',
    'refund_body' => 'You have been processed a refund of :amount for invoice :invoice_number.',

    'currency_us_dollar' => 'US Dollar',
    'currency_british_pound' => 'British Pound',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danish Krone',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Swedish Krona',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese Dollar',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'We hope you\'re enjoying using the app.<br/>If you\'d consider :link we\'d greatly appreciate it!',
    'writing_a_review' => 'writing a review',

    'use_english_version' => 'Make sure to use the English version of the files.<br/>We use the column headers to match the fields.',
    'tax1' => 'First Tax',
    'tax2' => 'Second Tax',
    'fee_help' => 'Gateway fees are the costs charged for access to the financial networks that handle the processing of online payments.',
    'format_export' => 'Exporting format',
    'custom1' => 'First Custom',
    'custom2' => 'Second Custom',
    'contact_first_name' => 'Contact First Name',
    'contact_last_name' => 'Contact Last Name',
    'contact_custom1' => 'Contact First Custom',
    'contact_custom2' => 'Contact Second Custom',
    'currency' => 'Currency',
    'ofx_help' => 'To troubleshoot check for comments on :ofxhome_link and test with :ofxget_link.',
    'comments' => 'comments',

    'item_product' => 'Item Product',
    'item_notes' => 'Item Notes',
    'item_cost' => 'Item Cost',
    'item_quantity' => 'Item Quantity',
    'item_tax_rate' => 'Item Tax Rate',
    'item_tax_name' => 'Item Tax Name',
    'item_tax1' => 'Item Tax1',
    'item_tax2' => 'Item Tax2',

    'delete_company' => 'Delete Company',
    'delete_company_help' => 'Permanently delete the company along with all data and setting.',
    'delete_company_message' => 'Warning: This will permanently delete your company, there is no undo.',

    'applied_discount' => 'The coupon has been applied, the plan price has been reduced by :discount%.',
    'applied_free_year' => 'The coupon has been applied, your account has been upgraded to pro for one year.',

    'contact_us_help' => 'If you\'re reporting an error please include any relevant logs from storage/logs/laravel-error.log',
    'include_errors' => 'Include Errors',
    'include_errors_help' => 'Include :link from storage/logs/laravel-error.log',
    'recent_errors' => 'recent errors',
    'customer' => 'Customer',
    'customers' => 'Customers',
    'created_customer' => 'Successfully created customer',
    'created_customers' => 'Successfully created :count customers',

    'purge_details' => 'The data in your company (:account) has been successfully purged.',
    'deleted_company' => 'Successfully deleted company',
    'deleted_account' => 'Successfully canceled account',
    'deleted_company_details' => 'Your company (:account) has been successfully deleted.',
    'deleted_account_details' => 'Your account (:account) has been successfully deleted.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Accept Alipay',
    'enable_sofort' => 'Accept EU bank transfers',
    'stripe_alipay_help' => 'These gateways also need to be activated in :link.',
    'calendar' => 'Calendar',
    'pro_plan_calendar' => ':link to enable the calendar by joining the Pro Plan',

    'what_are_you_working_on' => 'What are you working on?',
    'time_tracker' => 'Time Tracker',
    'refresh' => 'Refresh',
    'filter_sort' => 'Filter/Sort',
    'no_description' => 'No Description',
    'time_tracker_login' => 'Time Tracker Login',
    'save_or_discard' => 'Save or discard your changes',
    'discard_changes' => 'Discard Changes',
    'tasks_not_enabled' => 'Tasks are not enabled.',
    'started_task' => 'Successfully started task',
    'create_client' => 'Create Client',

    'download_desktop_app' => 'Download the desktop app',
    'download_iphone_app' => 'Download the iPhone app',
    'download_android_app' => 'Download the Android app',
    'time_tracker_mobile_help' => 'Double tap a task to select it',
    'stopped' => 'Stopped',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
    'sort_field' => 'Sort By',
    'sort_direction' => 'Direction',
    'discard' => 'Discard',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'mins',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Clear',
    'warn_payment_gateway' => 'Note: accepting online payments requires a payment gateway, :link to add one.',
    'task_rate' => 'Task Rate',
    'task_rate_help' => 'Set the default rate for invoiced tasks.',
    'past_due' => 'Past Due',
    'document' => 'Document',
    'invoice_or_expense' => 'Invoice/Expense',
    'invoice_pdfs' => 'Invoice PDFs',
    'enable_sepa' => 'Accept SEPA',
    'enable_bitcoin' => 'Accept Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'By providing your IBAN and confirming this payment, you are authorizing :company and Stripe, our payment service provider, to send instructions to your bank to debit your account and your bank to debit your account in accordance with those instructions. You are entitled to a refund from your bank under the terms and conditions of your agreement with your bank. A refund must be claimed within 8 weeks starting from the date on which your account was debited.',
    'recover_license' => 'Recover License',
    'purchase' => 'Purchase',
    'recover' => 'Recover',
    'apply' => 'Apply',
    'recover_white_label_header' => 'Recover White Label License',
    'apply_white_label_header' => 'Apply White Label License',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Return to Invoice',
    'gateway_help_13' => 'To use ITN leave the PDT Key field blank.',
    'partial_due_date' => 'Partial Due Date',
    'task_fields' => 'Task Fields',
    'product_fields_help' => 'Drag and drop fields to change their order',
    'custom_value1' => 'Custom Value',
    'custom_value2' => 'Custom Value',
    'enable_two_factor' => 'Two-Factor Authentication',
    'enable_two_factor_help' => 'Use your phone to confirm your identity when logging in',
    'two_factor_setup' => 'Two-Factor Setup',
    'two_factor_setup_help' => 'Scan the bar code with a :link compatible app.',
    'one_time_password' => 'One Time Password',
    'set_phone_for_two_factor' => 'Set your mobile phone number as a backup to enable.',
    'enabled_two_factor' => 'Successfully enabled Two-Factor Authentication',
    'add_product' => 'Add Product',
    'email_will_be_sent_on' => 'Note: the email will be sent on :date.',
    'invoice_product' => 'Invoice Product',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Error: local storage is not available.',
    'your_password_reset_link' => 'Your Password Reset Link',
    'subdomain_taken' => 'The subdomain is already in use',
    'client_login' => 'Client Login',
    'converted_amount' => 'Converted Amount',
    'default' => 'Default',
    'shipping_address' => 'Shipping Address',
    'bllling_address' => 'Billing Address',
    'billing_address1' => 'Billing Street',
    'billing_address2' => 'Billing Apt/Suite',
    'billing_city' => 'Billing City',
    'billing_state' => 'Billing State/Province',
    'billing_postal_code' => 'Billing Postal Code',
    'billing_country' => 'Billing Country',
    'shipping_address1' => 'Shipping Street',
    'shipping_address2' => 'Shipping Apt/Suite',
    'shipping_city' => 'Shipping City',
    'shipping_state' => 'Shipping State/Province',
    'shipping_postal_code' => 'Shipping Postal Code',
    'shipping_country' => 'Shipping Country',
    'classify' => 'Classify',
    'show_shipping_address_help' => 'Require client to provide their shipping address',
    'ship_to_billing_address' => 'Ship to billing address',
    'delivery_note' => 'Delivery Note',
    'show_tasks_in_portal' => 'Show tasks in the client portal',
    'cancel_schedule' => 'Cancel Schedule',
    'scheduled_report' => 'Scheduled Report',
    'scheduled_report_help' => 'Email the :report report as :format to :email',
    'created_scheduled_report' => 'Successfully scheduled report',
    'deleted_scheduled_report' => 'Successfully canceled scheduled report',
    'scheduled_report_attached' => 'Your scheduled :type report is attached.',
    'scheduled_report_error' => 'Failed to create schedule report',
    'invalid_one_time_password' => 'Invalid one time password',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accept Apple Pay and Pay with Google',
    'requires_subdomain' => 'This payment type requires that a :link.',
    'subdomain_is_set' => 'subdomain is set',
    'verification_file' => 'Verification File',
    'verification_file_missing' => 'The verification file is needed to accept payments.',
    'apple_pay_domain' => 'Use <code>:domain</code> as the domain in :link.',
    'apple_pay_not_supported' => 'Sorry, Apple/Google Pay isn\'t supported by your browser',
    'optional_payment_methods' => 'Optional Payment Methods',
    'add_subscription' => 'Add Subscription',
    'target_url' => 'Target',
    'target_url_help' => 'When the selected event occurs the app will post the entity to the target URL.',
    'event' => 'Event',
    'subscription_event_1' => 'Created Client',
    'subscription_event_2' => 'Created Invoice',
    'subscription_event_3' => 'Created Quote',
    'subscription_event_4' => 'Created Payment',
    'subscription_event_5' => 'Created Vendor',
    'subscription_event_6' => 'Updated Quote',
    'subscription_event_7' => 'Deleted Quote',
    'subscription_event_8' => 'Updated Invoice',
    'subscription_event_9' => 'Deleted Invoice',
    'subscription_event_10' => 'Updated Client',
    'subscription_event_11' => 'Deleted Client',
    'subscription_event_12' => 'Deleted Payment',
    'subscription_event_13' => 'Updated Vendor',
    'subscription_event_14' => 'Deleted Vendor',
    'subscription_event_15' => 'Created Expense',
    'subscription_event_16' => 'Updated Expense',
    'subscription_event_17' => 'Deleted Expense',
    'subscription_event_18' => 'Created Task',
    'subscription_event_19' => 'Updated Task',
    'subscription_event_20' => 'Deleted Task',
    'subscription_event_21' => 'Approved Quote',
    'subscriptions' => 'Subscriptions',
    'updated_subscription' => 'Successfully updated subscription',
    'created_subscription' => 'Successfully created subscription',
    'edit_subscription' => 'Edit Subscription',
    'archive_subscription' => 'Archive Subscription',
    'archived_subscription' => 'Successfully archived subscription',
    'project_error_multiple_clients' => 'The projects can\'t belong to different clients',
    'invoice_project' => 'Invoice Project',
    'module_recurring_invoice' => 'Recurring Invoices',
    'module_credit' => 'Credits',
    'module_quote' => 'Quotes & Proposals',
    'module_task' => 'Tasks & Projects',
    'module_expense' => 'Expenses & Vendors',
    'module_ticket' => 'Tickets',
    'reminders' => 'Reminders',
    'send_client_reminders' => 'Send email reminders',
    'can_view_tasks' => 'Tasks are visible in the portal',
    'is_not_sent_reminders' => 'Reminders are not sent',
    'promotion_footer' => 'Your promotion will expire soon, :link to upgrade now.',
    'unable_to_delete_primary' => 'Note: to delete this company first delete all linked companies.',
    'please_register' => 'Please register your account',
    'processing_request' => 'Processing request',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Edit Times',
    'inclusive_taxes_help' => 'Include <b>taxes in the cost</b>',
    'inclusive_taxes_notice' => 'This setting can not be changed once an invoice has been created.',
    'inclusive_taxes_warning' => 'Warning: existing invoices will need to be resaved',
    'copy_shipping' => 'Copy Shipping',
    'copy_billing' => 'Copy Billing',
    'quote_has_expired' => 'The quote has expired, please contact the merchant.',
    'empty_table_footer' => 'Showing 0 to 0 of 0 entries',
    'do_not_trust' => 'Do not remember this device',
    'trust_for_30_days' => 'Trust for 30 days',
    'trust_forever' => 'Trust forever',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Ready to do',
    'in_progress' => 'In progress',
    'add_status' => 'Add status',
    'archive_status' => 'Archive Status',
    'new_status' => 'New Status',
    'convert_products' => 'Convert Products',
    'convert_products_help' => 'Automatically convert product prices to the client\'s currency',
    'improve_client_portal_link' => 'Set a subdomain to shorten the client portal link.',
    'budgeted_hours' => 'Budgeted Hours',
    'progress' => 'Progress',
    'view_project' => 'View Project',
    'summary' => 'Summary',
    'endless_reminder' => 'Endless Reminder',
    'signature_on_invoice_help' => 'Add the following code to show your client\'s signature on the PDF.',
    'signature_on_pdf' => 'Show on PDF',
    'signature_on_pdf_help' => 'Show the client signature on the invoice/quote PDF.',
    'expired_white_label' => 'The white label license has expired',
    'return_to_login' => 'Return to Login',
    'convert_products_tip' => 'Note: add a :link named ":name" to see the exchange rate.',
    'amount_greater_than_balance' => 'The amount is greater than the invoice balance, a credit will be created with the remaining amount.',
    'custom_fields_tip' => 'Use <code>Label|Option1,Option2</code> to show a select box.',
    'client_information' => 'Client Information',
    'updated_client_details' => 'Successfully updated client details',
    'auto' => 'Auto',
    'tax_amount' => 'Tax Amount',
    'tax_paid' => 'Tax Paid',
    'none' => 'None',
    'proposal_message_button' => 'To view your proposal for :amount, click the button below.',
    'proposal' => 'Proposal',
    'proposals' => 'Proposals',
    'list_proposals' => 'List Proposals',
    'new_proposal' => 'New Proposal',
    'edit_proposal' => 'Edit Proposal',
    'archive_proposal' => 'Archive Proposal',
    'delete_proposal' => 'Delete Proposal',
    'created_proposal' => 'Successfully created proposal',
    'updated_proposal' => 'Successfully updated proposal',
    'archived_proposal' => 'Successfully archived proposal',
    'deleted_proposal' => 'Successfully archived proposal',
    'archived_proposals' => 'Successfully archived :count proposals',
    'deleted_proposals' => 'Successfully archived :count proposals',
    'restored_proposal' => 'Successfully restored proposal',
    'restore_proposal' => 'Restore Proposal',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'New Snippet',
    'edit_proposal_snippet' => 'Edit Snippet',
    'archive_proposal_snippet' => 'Archive Snippet',
    'delete_proposal_snippet' => 'Delete Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'Template',
    'templates' => 'Templates',
    'proposal_template' => 'Template',
    'proposal_templates' => 'Templates',
    'new_proposal_template' => 'New Template',
    'edit_proposal_template' => 'Edit Template',
    'archive_proposal_template' => 'Archive Template',
    'delete_proposal_template' => 'Delete Template',
    'created_proposal_template' => 'Successfully created template',
    'updated_proposal_template' => 'Successfully updated template',
    'archived_proposal_template' => 'Successfully archived template',
    'deleted_proposal_template' => 'Successfully archived template',
    'archived_proposal_templates' => 'Successfully archived :count templates',
    'deleted_proposal_templates' => 'Successfully archived :count templates',
    'restored_proposal_template' => 'Successfully restored template',
    'restore_proposal_template' => 'Restore Template',
    'proposal_category' => 'Category',
    'proposal_categories' => 'Categories',
    'new_proposal_category' => 'New Category',
    'edit_proposal_category' => 'Edit Category',
    'archive_proposal_category' => 'Archive Category',
    'delete_proposal_category' => 'Delete Category',
    'created_proposal_category' => 'Successfully created category',
    'updated_proposal_category' => 'Successfully updated category',
    'archived_proposal_category' => 'Successfully archived category',
    'deleted_proposal_category' => 'Successfully archived category',
    'archived_proposal_categories' => 'Successfully archived :count categories',
    'deleted_proposal_categories' => 'Successfully archived :count categories',
    'restored_proposal_category' => 'Successfully restored category',
    'restore_proposal_category' => 'Restore Category',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Icon',
    'proposal_not_found' => 'The requested proposal is not available',
    'create_proposal_category' => 'Create category',
    'clone_proposal_template' => 'Clone Template',
    'proposal_email' => 'Proposal Email',
    'proposal_subject' => 'New proposal :number from :account',
    'proposal_message' => 'To view your proposal for :amount, click the link below.',
    'emailed_proposal' => 'Successfully emailed proposal',
    'load_template' => 'Load Template',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Add Image',
    'select_image' => 'Select Image',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Delete Image',
    'delete_image_help' => 'Warning: deleting the image will remove it from all proposals.',
    'amount_variable_help' => 'Note: the invoice $amount field will use the partial/deposit field if set otherwise it will use the invoice balance.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The refund will be recorded in the app but will NOT be processed by the payment gateway.',
    'email_address_changed' => 'Email address has been changed',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting to ZIP requires the GMP extension',
    'email_history' => 'Email History',
    'loading' => 'Loading',
    'no_messages_found' => 'No messages found',
    'processing' => 'Processing',
    'reactivate' => 'Reactivate',
    'reactivated_email' => 'The email address has been reactivated',
    'emails' => 'Emails',
    'opened' => 'Opened',
    'bounced' => 'Bounced',
    'total_sent' => 'Total Sent',
    'total_opened' => 'Total Opened',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'Email Clients',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Group',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'You\'ve received a new payment!',
    'slack_webhook_help' => 'Receive payment notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'Successfully accepted the latest terms of service',
    'invalid_url' => 'Invalid URL',
    'workflow_settings' => 'Workflow Settings',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automatically email recurring invoices when they are created.',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Automatically archive invoices when they are paid.',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Automatically archive quotes when they are converted.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Allow approve expired quote',
    'allow_approve_expired_quote_help' => 'Allow clients to approve expired quotes.',
    'invoice_workflow' => 'Invoice Workflow',
    'quote_workflow' => 'Quote Workflow',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'All related records (invoices, tasks, expenses, documents, etc) will also be deleted.',
    'clone_product' => 'Clone Product',
    'item_details' => 'Item Details',
    'send_item_details_help' => 'Send line item details to the payment gateway.',
    'view_proposal' => 'View Proposal',
    'view_in_portal' => 'View in Portal',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'vendor will be created',
    'vendors_will_create' => 'vendors will be created',
    'created_vendors' => 'Successfully created :count vendor(s)',
    'import_vendors' => 'Import Vendors',
    'company' => 'Company',
    'client_field' => 'Client Field',
    'contact_field' => 'Contact Field',
    'product_field' => 'Product Field',
    'task_field' => 'Task Field',
    'project_field' => 'Project Field',
    'expense_field' => 'Expense Field',
    'vendor_field' => 'Vendor Field',
    'company_field' => 'Company Field',
    'invoice_field' => 'Invoice Field',
    'invoice_surcharge' => 'Invoice Surcharge',
    'custom_task_fields_help' => 'Add a field when creating a task.',
    'custom_project_fields_help' => 'Add a field when creating a project.',
    'custom_expense_fields_help' => 'Add a field when creating an expense.',
    'custom_vendor_fields_help' => 'Add a field when creating a vendor.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Unpaid Invoice',
    'paid_invoice' => 'Paid Invoice',
    'unapproved_quote' => 'Unapproved Quote',
    'unapproved_proposal' => 'Unapproved Proposal',
    'autofills_city_state' => 'Auto-fills city/state',
    'no_match_found' => 'No match found',
    'password_strength' => 'Password Strength',
    'strength_weak' => 'Weak',
    'strength_good' => 'Good',
    'strength_strong' => 'Strong',
    'mark' => 'Mark',
    'updated_task_status' => 'Successfully update task status',
    'background_image' => 'Background Image',
    'background_image_help' => 'Use the :link to manage your images, we recommend using a small file.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Gateway Fee Item',
    'gateway_fee_description' => 'Gateway Fee Surcharge',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Show Payments',
    'show_aging' => 'Show Aging',
    'reference' => 'Reference',
    'amount_paid' => 'Amount Paid',
    'send_notifications_for' => 'Send Notifications For',
    'all_invoices' => 'All Invoices',
    'my_invoices' => 'My Invoices',
    'payment_reference' => 'Payment Reference',
    'maximum' => 'Maximum',
    'sort' => 'Sort',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => 'Please enter your email',
    'please_enter_your_password' => 'Please enter your password',
    'please_enter_your_url' => 'Please enter your URL',
    'please_enter_a_product_key' => 'Please enter a product key',
    'an_error_occurred' => 'An error occurred',
    'overview' => 'Overview',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Error',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Additional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Add Item',
    'total_amount' => 'Total Amount',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Invoice Status',
    'click_plus_to_add_item' => 'Click + to add an item',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => 'Please select a date',
    'please_select_a_client' => 'Please select a client',
    'language' => 'Language',
    'updated_at' => 'Updated',
    'please_enter_an_invoice_number' => 'Please enter an invoice number',
    'please_enter_a_quote_number' => 'Please enter a quote number',
    'clients_invoices' => ':client\'s invoices',
    'viewed' => 'Viewed',
    'approved' => 'Approved',
    'invoice_status_1' => 'Draft',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Viewed',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Paid',
    'marked_invoice_as_sent' => 'Successfully marked invoice as sent',
    'please_enter_a_client_or_contact_name' => 'Please enter a client or contact name',
    'restart_app_to_apply_change' => 'Restart the app to apply the change',
    'refresh_data' => 'Refresh Data',
    'blank_contact' => 'Blank Contact',
    'no_records_found' => 'No records found',
    'industry' => 'Industry',
    'size' => 'Size',
    'net' => 'Net',
    'show_tasks' => 'Show tasks',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Send',
    'auto_billing' => 'Auto billing',
    'button' => 'Button',
    'more' => 'More',
    'edit_recurring_invoice' => 'Edit Recurring Invoice',
    'edit_recurring_quote' => 'Edit Recurring Quote',
    'quote_status' => 'Quote Status',
    'please_select_an_invoice' => 'Please select an invoice',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'Payment Status',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'Send receipt to the client',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Successfully marked quote as sent',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'New Ticket',
    'edit_ticket' => 'Edit Ticket',
    'view_ticket' => 'View Ticket',
    'archive_ticket' => 'Archive Ticket',
    'restore_ticket' => 'Restore Ticket',
    'delete_ticket' => 'Delete Ticket',
    'archived_ticket' => 'Successfully archived ticket',
    'archived_tickets' => 'Successfully archived tickets',
    'restored_ticket' => 'Successfully restored ticket',
    'deleted_ticket' => 'Successfully deleted ticket',
    'open' => 'Open',
    'new' => 'New',
    'closed' => 'Closed',
    'reopened' => 'Reopened',
    'priority' => 'Priority',
    'last_updated' => 'Last Updated',
    'comment' => 'Comments',
    'tags' => 'Tags',
    'linked_objects' => 'Linked Objects',
    'low' => 'Low',
    'medium' => 'Medium',
    'high' => 'High',
    'no_due_date' => 'No due date set',
    'assigned_to' => 'Assigned to',
    'reply' => 'Reply',
    'awaiting_reply' => 'Awaiting reply',
    'ticket_close' => 'Close Ticket',
    'ticket_reopen' => 'Reopen Ticket',
    'ticket_open' => 'Open Ticket',
    'ticket_split' => 'Split Ticket',
    'ticket_merge' => 'Merge Ticket',
    'ticket_update' => 'Update Ticket',
    'ticket_settings' => 'Ticket Settings',
    'updated_ticket' => 'Ticket Updated',
    'mark_spam' => 'Mark as Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Name taken',
    'local_part_available' => 'Name available',
    'local_part_invalid' => 'Invalid name (alpha numeric only, no spaces',
    'local_part_help' => 'Customize the local part of your inbound support email, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Attachments',
    'client_upload' => 'Client uploads',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Maximum file size',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Ticket number must be greater than the current ticket number',
    'new_ticket_template_id' => 'New ticket',
    'new_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a new ticket is created',
    'update_ticket_template_id' => 'Updated ticket',
    'update_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is updated',
    'close_ticket_template_id' => 'Closed ticket',
    'close_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is closed',
    'default_priority' => 'Default priority',
    'alert_new_comment_id' => 'New comment',
    'alert_comment_ticket_help' => 'Selecting a template will send a notification (to agent) when a comment is made.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Additional new ticket notifications',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticket assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Ticket overdue',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Default Agent',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Show agent details on responses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'Ticket not found',
    'add_template' => 'Add Template',
    'ticket_template' => 'Ticket Template',
    'ticket_templates' => 'Ticket Templates',
    'updated_ticket_template' => 'Updated Ticket Template',
    'created_ticket_template' => 'Created Ticket Template',
    'archive_ticket_template' => 'Archive Template',
    'restore_ticket_template' => 'Restore Template',
    'archived_ticket_template' => 'Successfully archived template',
    'restored_ticket_template' => 'Successfully restored template',
    'close_reason' => 'Let us know why you are closing this ticket',
    'reopen_reason' => 'Let us know why you are reopening this ticket',
    'enter_ticket_message' => 'Please enter a message to update the ticket',
    'show_hide_all' => 'Show / Hide all',
    'subject_required' => 'Subject required',
    'mobile_refresh_warning' => 'If you\'re using the mobile app you may need to do a full refresh.',
    'enable_proposals_for_background' => 'To upload a background image :link to enable the proposals module.',
    'ticket_assignment' => 'Ticket :ticket_number has been assigned to :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number has been updated by client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number has been created.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number has been updated.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number has been closed.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is now overdue',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Parent Ticket',
    'linked_tickets' => 'Linked Tickets',
    'merge_prompt' => 'Enter ticket number to merge into',
    'merge_from_to' => 'Ticket #:old_ticket merged into Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket was closed and merged into Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket was closed and merged into this ticket',
    'merge_placeholder' => 'Merge ticket #:ticket into the following ticket',
    'select_ticket' => 'Select Ticket',
    'new_internal_ticket' => 'New internal ticket',
    'internal_ticket' => 'Internal ticket',
    'create_ticket' => 'Create ticket',
    'allow_inbound_email_tickets_external' => 'New Tickets by email (Client)',
    'allow_inbound_email_tickets_external_help' => 'Allow clients to create new tickets by email',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compare',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Today',
    'current' => 'Current',
    'previous' => 'Previous',
    'current_period' => 'Current Period',
    'comparison_period' => 'Comparison Period',
    'previous_period' => 'Previous Period',
    'previous_year' => 'Previous Year',
    'compare_to' => 'Compare to',
    'last_week' => 'Last Week',
    'clone_to_invoice' => 'Clone to Invoice',
    'clone_to_quote' => 'Clone to Quote',
    'convert' => 'Convert',
    'last7_days' => 'Last 7 Days',
    'last30_days' => 'Last 30 Days',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Show product details',
    'show_product_notes_help' => 'Include the <b>description and cost</b> in the product dropdown',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Thank you for using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'Average',
    'unapproved' => 'Unapproved',
    'authenticate_to_change_setting' => 'Please authenticate to change this setting',
    'locked' => 'Locked',
    'authenticate' => 'Authenticate',
    'please_authenticate' => 'Please authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'Please enter a name',
    'click_plus_to_add_time' => 'Click + to add time',
    'design' => 'Design',
    'password_is_too_short' => 'Password is too short',
    'failed_to_find_record' => 'Failed to find record',
    'valid_until_days' => 'Valid Until',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Days',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Take Picture',
    'upload_file' => 'Upload File',
    'new_document' => 'New Document',
    'edit_document' => 'Edit Document',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'No History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'No record selected',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual Subscription',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count users',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Please enter a first name',
    'please_enter_a_last_name' => 'Please enter a last name',
    'please_agree_to_terms_and_privacy' => 'Please agree to the terms of service and privacy policy to create an account.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'terms of service',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'View Website',
    'create_account' => 'Create Account',
    'email_login' => 'Email Login',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Company Value',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'First Day of the Week',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtered by Vendor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Upload Logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Device Settings',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Price',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
